import { HTTPClient, HTTPClientResponse } from '../../client.js';
import JSONRequest from '../jsonrequest.js';
import { Box } from './models/types.js';
/**
 * Given an application ID and the box name (key), return the value stored in the box.
 *
 * #### Example
 * ```typescript
 * const index = 60553466;
 * const boxName = Buffer.from("foo");
 * const boxResponse = await algodClient.getApplicationBoxByName(index, boxName).do();
 * const boxValue = boxResponse.value;
 * ```
 *
 * [Response data schema details](https://developer.algorand.org/docs/rest-apis/algod/#get-v2applicationsapplication-idbox)
 * @param index - The application ID to look up.
 * @category GET
 */
export default class GetApplicationBoxByName extends JSONRequest<Box> {
    private index;
    constructor(c: HTTPClient, index: number | bigint, name: Uint8Array);
    /**
     * @returns `/v2/applications/${index}/box`
     */
    path(): string;
    prepare(response: HTTPClientResponse): Box;
}
