/**
 * NOTICE: This file was generated. Editing this file manually is not recommended.
 */
import { Encodable, Schema } from '../../../../encoding/encoding.js';
import { Block } from '../../../../types/block.js';
import { LedgerStateDelta } from '../../../../types/statedelta.js';
import { SignedTransaction } from '../../../../signedTransaction.js';
import { Address } from '../../../../encoding/address.js';
import { UntypedValue } from '../../untypedmodel.js';
/**
 * Account information at a given round.
 * Definition:
 * data/basics/userBalance.go : AccountData
 */
export declare class Account implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * the account public key
     */
    address: string;
    /**
     * (algo) total number of MicroAlgos in the account
     */
    amount: bigint;
    /**
     * specifies the amount of MicroAlgos in the account, without the pending rewards.
     */
    amountWithoutPendingRewards: bigint;
    /**
     * MicroAlgo balance required by the account.
     * The requirement grows based on asset and application usage.
     */
    minBalance: bigint;
    /**
     * amount of MicroAlgos of pending rewards in this account.
     */
    pendingRewards: bigint;
    /**
     * (ern) total rewards of MicroAlgos the account has received, including pending
     * rewards.
     */
    rewards: bigint;
    /**
     * The round for which this information is relevant.
     */
    round: bigint;
    /**
     * (onl) delegation status of the account's MicroAlgos
     * * Offline - indicates that the associated account is delegated.
     * * Online - indicates that the associated account used as part of the delegation
     * pool.
     * * NotParticipating - indicates that the associated account is neither a
     * delegator nor a delegate.
     */
    status: string;
    /**
     * The count of all applications that have been opted in, equivalent to the count
     * of application local data (AppLocalState objects) stored in this account.
     */
    totalAppsOptedIn: number;
    /**
     * The count of all assets that have been opted in, equivalent to the count of
     * AssetHolding objects held by this account.
     */
    totalAssetsOptedIn: number;
    /**
     * The count of all apps (AppParams objects) created by this account.
     */
    totalCreatedApps: number;
    /**
     * The count of all assets (AssetParams objects) created by this account.
     */
    totalCreatedAssets: number;
    /**
     * (appl) applications local data stored in this account.
     * Note the raw object uses `map[int] -> AppLocalState` for this type.
     */
    appsLocalState?: ApplicationLocalState[];
    /**
     * (teap) the sum of all extra application program pages for this account.
     */
    appsTotalExtraPages?: number;
    /**
     * (tsch) stores the sum of all of the local schemas and global schemas in this
     * account.
     * Note: the raw account uses `StateSchema` for this type.
     */
    appsTotalSchema?: ApplicationStateSchema;
    /**
     * (asset) assets held by this account.
     * Note the raw object uses `map[int] -> AssetHolding` for this type.
     */
    assets?: AssetHolding[];
    /**
     * (spend) the address against which signing should be checked. If empty, the
     * address of the current account is used. This field can be updated in any
     * transaction by setting the RekeyTo field.
     */
    authAddr?: Address;
    /**
     * (appp) parameters of applications created by this account including app global
     * data.
     * Note: the raw account uses `map[int] -> AppParams` for this type.
     */
    createdApps?: Application[];
    /**
     * (apar) parameters of assets created by this account.
     * Note: the raw account uses `map[int] -> Asset` for this type.
     */
    createdAssets?: Asset[];
    /**
     * Whether or not the account can receive block incentives if its balance is in
     * range at proposal time.
     */
    incentiveEligible?: boolean;
    /**
     * The round in which this account last went online, or explicitly renewed their
     * online status.
     */
    lastHeartbeat?: number;
    /**
     * The round in which this account last proposed the block.
     */
    lastProposed?: number;
    /**
     * AccountParticipation describes the parameters used by this account in consensus
     * protocol.
     */
    participation?: AccountParticipation;
    /**
     * (ebase) used as part of the rewards computation. Only applicable to accounts
     * which are participating.
     */
    rewardBase?: bigint;
    /**
     * Indicates what type of signature is used by this account, must be one of:
     * * sig
     * * msig
     * * lsig
     */
    sigType?: string;
    /**
     * (tbxb) The total number of bytes used by this account's app's box keys and
     * values.
     */
    totalBoxBytes?: number;
    /**
     * (tbx) The number of existing boxes created by this account's app.
     */
    totalBoxes?: number;
    /**
     * Creates a new `Account` object.
     * @param address - the account public key
     * @param amount - (algo) total number of MicroAlgos in the account
     * @param amountWithoutPendingRewards - specifies the amount of MicroAlgos in the account, without the pending rewards.
     * @param minBalance - MicroAlgo balance required by the account.
     * The requirement grows based on asset and application usage.
     * @param pendingRewards - amount of MicroAlgos of pending rewards in this account.
     * @param rewards - (ern) total rewards of MicroAlgos the account has received, including pending
     * rewards.
     * @param round - The round for which this information is relevant.
     * @param status - (onl) delegation status of the account's MicroAlgos
     * * Offline - indicates that the associated account is delegated.
     * * Online - indicates that the associated account used as part of the delegation
     * pool.
     * * NotParticipating - indicates that the associated account is neither a
     * delegator nor a delegate.
     * @param totalAppsOptedIn - The count of all applications that have been opted in, equivalent to the count
     * of application local data (AppLocalState objects) stored in this account.
     * @param totalAssetsOptedIn - The count of all assets that have been opted in, equivalent to the count of
     * AssetHolding objects held by this account.
     * @param totalCreatedApps - The count of all apps (AppParams objects) created by this account.
     * @param totalCreatedAssets - The count of all assets (AssetParams objects) created by this account.
     * @param appsLocalState - (appl) applications local data stored in this account.
     * Note the raw object uses `map[int] -> AppLocalState` for this type.
     * @param appsTotalExtraPages - (teap) the sum of all extra application program pages for this account.
     * @param appsTotalSchema - (tsch) stores the sum of all of the local schemas and global schemas in this
     * account.
     * Note: the raw account uses `StateSchema` for this type.
     * @param assets - (asset) assets held by this account.
     * Note the raw object uses `map[int] -> AssetHolding` for this type.
     * @param authAddr - (spend) the address against which signing should be checked. If empty, the
     * address of the current account is used. This field can be updated in any
     * transaction by setting the RekeyTo field.
     * @param createdApps - (appp) parameters of applications created by this account including app global
     * data.
     * Note: the raw account uses `map[int] -> AppParams` for this type.
     * @param createdAssets - (apar) parameters of assets created by this account.
     * Note: the raw account uses `map[int] -> Asset` for this type.
     * @param incentiveEligible - Whether or not the account can receive block incentives if its balance is in
     * range at proposal time.
     * @param lastHeartbeat - The round in which this account last went online, or explicitly renewed their
     * online status.
     * @param lastProposed - The round in which this account last proposed the block.
     * @param participation - AccountParticipation describes the parameters used by this account in consensus
     * protocol.
     * @param rewardBase - (ebase) used as part of the rewards computation. Only applicable to accounts
     * which are participating.
     * @param sigType - Indicates what type of signature is used by this account, must be one of:
     * * sig
     * * msig
     * * lsig
     * @param totalBoxBytes - (tbxb) The total number of bytes used by this account's app's box keys and
     * values.
     * @param totalBoxes - (tbx) The number of existing boxes created by this account's app.
     */
    constructor({ address, amount, amountWithoutPendingRewards, minBalance, pendingRewards, rewards, round, status, totalAppsOptedIn, totalAssetsOptedIn, totalCreatedApps, totalCreatedAssets, appsLocalState, appsTotalExtraPages, appsTotalSchema, assets, authAddr, createdApps, createdAssets, incentiveEligible, lastHeartbeat, lastProposed, participation, rewardBase, sigType, totalBoxBytes, totalBoxes, }: {
        address: string;
        amount: number | bigint;
        amountWithoutPendingRewards: number | bigint;
        minBalance: number | bigint;
        pendingRewards: number | bigint;
        rewards: number | bigint;
        round: number | bigint;
        status: string;
        totalAppsOptedIn: number | bigint;
        totalAssetsOptedIn: number | bigint;
        totalCreatedApps: number | bigint;
        totalCreatedAssets: number | bigint;
        appsLocalState?: ApplicationLocalState[];
        appsTotalExtraPages?: number | bigint;
        appsTotalSchema?: ApplicationStateSchema;
        assets?: AssetHolding[];
        authAddr?: Address | string;
        createdApps?: Application[];
        createdAssets?: Asset[];
        incentiveEligible?: boolean;
        lastHeartbeat?: number | bigint;
        lastProposed?: number | bigint;
        participation?: AccountParticipation;
        rewardBase?: number | bigint;
        sigType?: string;
        totalBoxBytes?: number | bigint;
        totalBoxes?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): Account;
}
/**
 * AccountApplicationResponse describes the account's application local state and
 * global state (AppLocalState and AppParams, if either exists) for a specific
 * application ID. Global state will only be returned if the provided address is
 * the application's creator.
 */
export declare class AccountApplicationResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The round for which this information is relevant.
     */
    round: bigint;
    /**
     * (appl) the application local data stored in this account.
     * The raw account uses `AppLocalState` for this type.
     */
    appLocalState?: ApplicationLocalState;
    /**
     * (appp) parameters of the application created by this account including app
     * global data.
     * The raw account uses `AppParams` for this type.
     */
    createdApp?: ApplicationParams;
    /**
     * Creates a new `AccountApplicationResponse` object.
     * @param round - The round for which this information is relevant.
     * @param appLocalState - (appl) the application local data stored in this account.
     * The raw account uses `AppLocalState` for this type.
     * @param createdApp - (appp) parameters of the application created by this account including app
     * global data.
     * The raw account uses `AppParams` for this type.
     */
    constructor({ round, appLocalState, createdApp, }: {
        round: number | bigint;
        appLocalState?: ApplicationLocalState;
        createdApp?: ApplicationParams;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AccountApplicationResponse;
}
/**
 * AccountAssetHolding describes the account's asset holding and asset parameters
 * (if either exist) for a specific asset ID.
 */
export declare class AccountAssetHolding implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (asset) Details about the asset held by this account.
     * The raw account uses `AssetHolding` for this type.
     */
    assetHolding: AssetHolding;
    /**
     * (apar) parameters of the asset held by this account.
     * The raw account uses `AssetParams` for this type.
     */
    assetParams?: AssetParams;
    /**
     * Creates a new `AccountAssetHolding` object.
     * @param assetHolding - (asset) Details about the asset held by this account.
     * The raw account uses `AssetHolding` for this type.
     * @param assetParams - (apar) parameters of the asset held by this account.
     * The raw account uses `AssetParams` for this type.
     */
    constructor({ assetHolding, assetParams, }: {
        assetHolding: AssetHolding;
        assetParams?: AssetParams;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AccountAssetHolding;
}
/**
 * AccountAssetResponse describes the account's asset holding and asset parameters
 * (if either exist) for a specific asset ID. Asset parameters will only be
 * returned if the provided address is the asset's creator.
 */
export declare class AccountAssetResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The round for which this information is relevant.
     */
    round: bigint;
    /**
     * (asset) Details about the asset held by this account.
     * The raw account uses `AssetHolding` for this type.
     */
    assetHolding?: AssetHolding;
    /**
     * (apar) parameters of the asset created by this account.
     * The raw account uses `AssetParams` for this type.
     */
    createdAsset?: AssetParams;
    /**
     * Creates a new `AccountAssetResponse` object.
     * @param round - The round for which this information is relevant.
     * @param assetHolding - (asset) Details about the asset held by this account.
     * The raw account uses `AssetHolding` for this type.
     * @param createdAsset - (apar) parameters of the asset created by this account.
     * The raw account uses `AssetParams` for this type.
     */
    constructor({ round, assetHolding, createdAsset, }: {
        round: number | bigint;
        assetHolding?: AssetHolding;
        createdAsset?: AssetParams;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AccountAssetResponse;
}
/**
 * AccountAssetsInformationResponse contains a list of assets held by an account.
 */
export declare class AccountAssetsInformationResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The round for which this information is relevant.
     */
    round: number;
    assetHoldings?: AccountAssetHolding[];
    /**
     * Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    nextToken?: string;
    /**
     * Creates a new `AccountAssetsInformationResponse` object.
     * @param round - The round for which this information is relevant.
     * @param assetHoldings -
     * @param nextToken - Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    constructor({ round, assetHoldings, nextToken, }: {
        round: number | bigint;
        assetHoldings?: AccountAssetHolding[];
        nextToken?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AccountAssetsInformationResponse;
}
/**
 * AccountParticipation describes the parameters used by this account in consensus
 * protocol.
 */
export declare class AccountParticipation implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (sel) Selection public key (if any) currently registered for this round.
     */
    selectionParticipationKey: Uint8Array;
    /**
     * (voteFst) First round for which this participation is valid.
     */
    voteFirstValid: bigint;
    /**
     * (voteKD) Number of subkeys in each batch of participation keys.
     */
    voteKeyDilution: bigint;
    /**
     * (voteLst) Last round for which this participation is valid.
     */
    voteLastValid: bigint;
    /**
     * (vote) root participation public key (if any) currently registered for this
     * round.
     */
    voteParticipationKey: Uint8Array;
    /**
     * (stprf) Root of the state proof key (if any)
     */
    stateProofKey?: Uint8Array;
    /**
     * Creates a new `AccountParticipation` object.
     * @param selectionParticipationKey - (sel) Selection public key (if any) currently registered for this round.
     * @param voteFirstValid - (voteFst) First round for which this participation is valid.
     * @param voteKeyDilution - (voteKD) Number of subkeys in each batch of participation keys.
     * @param voteLastValid - (voteLst) Last round for which this participation is valid.
     * @param voteParticipationKey - (vote) root participation public key (if any) currently registered for this
     * round.
     * @param stateProofKey - (stprf) Root of the state proof key (if any)
     */
    constructor({ selectionParticipationKey, voteFirstValid, voteKeyDilution, voteLastValid, voteParticipationKey, stateProofKey, }: {
        selectionParticipationKey: string | Uint8Array;
        voteFirstValid: number | bigint;
        voteKeyDilution: number | bigint;
        voteLastValid: number | bigint;
        voteParticipationKey: string | Uint8Array;
        stateProofKey?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AccountParticipation;
}
/**
 * Application state delta.
 */
export declare class AccountStateDelta implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    address: string;
    /**
     * Application state delta.
     */
    delta: EvalDeltaKeyValue[];
    /**
     * Creates a new `AccountStateDelta` object.
     * @param address -
     * @param delta - Application state delta.
     */
    constructor({ address, delta, }: {
        address: string;
        delta: EvalDeltaKeyValue[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AccountStateDelta;
}
/**
 * The logged messages from an app call along with the app ID and outer transaction
 * ID. Logs appear in the same order that they were emitted.
 */
export declare class AppCallLogs implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The application from which the logs were generated
     */
    applicationIndex: number;
    /**
     * An array of logs
     */
    logs: Uint8Array[];
    /**
     * The transaction ID of the outer app call that lead to these logs
     */
    txid: string;
    /**
     * Creates a new `AppCallLogs` object.
     * @param applicationIndex - The application from which the logs were generated
     * @param logs - An array of logs
     * @param txid - The transaction ID of the outer app call that lead to these logs
     */
    constructor({ applicationIndex, logs, txid, }: {
        applicationIndex: number | bigint;
        logs: Uint8Array[];
        txid: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AppCallLogs;
}
/**
 * Application index and its parameters
 */
export declare class Application implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (appidx) application index.
     */
    id: bigint;
    /**
     * (appparams) application parameters.
     */
    params: ApplicationParams;
    /**
     * Creates a new `Application` object.
     * @param id - (appidx) application index.
     * @param params - (appparams) application parameters.
     */
    constructor({ id, params, }: {
        id: number | bigint;
        params: ApplicationParams;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): Application;
}
/**
 * An application's initial global/local/box states that were accessed during
 * simulation.
 */
export declare class ApplicationInitialStates implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Application index.
     */
    id: bigint;
    /**
     * An application's global/local/box state.
     */
    appBoxes?: ApplicationKVStorage;
    /**
     * An application's global/local/box state.
     */
    appGlobals?: ApplicationKVStorage;
    /**
     * An application's initial local states tied to different accounts.
     */
    appLocals?: ApplicationKVStorage[];
    /**
     * Creates a new `ApplicationInitialStates` object.
     * @param id - Application index.
     * @param appBoxes - An application's global/local/box state.
     * @param appGlobals - An application's global/local/box state.
     * @param appLocals - An application's initial local states tied to different accounts.
     */
    constructor({ id, appBoxes, appGlobals, appLocals, }: {
        id: number | bigint;
        appBoxes?: ApplicationKVStorage;
        appGlobals?: ApplicationKVStorage;
        appLocals?: ApplicationKVStorage[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationInitialStates;
}
/**
 * An application's global/local/box state.
 */
export declare class ApplicationKVStorage implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Key-Value pairs representing application states.
     */
    kvs: AvmKeyValue[];
    /**
     * The address of the account associated with the local state.
     */
    account?: Address;
    /**
     * Creates a new `ApplicationKVStorage` object.
     * @param kvs - Key-Value pairs representing application states.
     * @param account - The address of the account associated with the local state.
     */
    constructor({ kvs, account, }: {
        kvs: AvmKeyValue[];
        account?: Address | string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationKVStorage;
}
/**
 * References an account's local state for an application.
 */
export declare class ApplicationLocalReference implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Address of the account with the local state.
     */
    account: Address;
    /**
     * Application ID of the local state application.
     */
    app: bigint;
    /**
     * Creates a new `ApplicationLocalReference` object.
     * @param account - Address of the account with the local state.
     * @param app - Application ID of the local state application.
     */
    constructor({ account, app, }: {
        account: Address | string;
        app: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationLocalReference;
}
/**
 * Stores local state associated with an application.
 */
export declare class ApplicationLocalState implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The application which this local state is for.
     */
    id: bigint;
    /**
     * (hsch) schema.
     */
    schema: ApplicationStateSchema;
    /**
     * (tkv) storage.
     */
    keyValue?: TealKeyValue[];
    /**
     * Creates a new `ApplicationLocalState` object.
     * @param id - The application which this local state is for.
     * @param schema - (hsch) schema.
     * @param keyValue - (tkv) storage.
     */
    constructor({ id, schema, keyValue, }: {
        id: number | bigint;
        schema: ApplicationStateSchema;
        keyValue?: TealKeyValue[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationLocalState;
}
/**
 * Stores the global information associated with an application.
 */
export declare class ApplicationParams implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (approv) approval program.
     */
    approvalProgram: Uint8Array;
    /**
     * (clearp) approval program.
     */
    clearStateProgram: Uint8Array;
    /**
     * The address that created this application. This is the address where the
     * parameters and global state for this application can be found.
     */
    creator: Address;
    /**
     * (epp) the amount of extra program pages available to this app.
     */
    extraProgramPages?: number;
    /**
     * (gs) global state
     */
    globalState?: TealKeyValue[];
    /**
     * (gsch) global schema
     */
    globalStateSchema?: ApplicationStateSchema;
    /**
     * (lsch) local schema
     */
    localStateSchema?: ApplicationStateSchema;
    /**
     * (v) the number of updates to the application programs
     */
    version?: number;
    /**
     * Creates a new `ApplicationParams` object.
     * @param approvalProgram - (approv) approval program.
     * @param clearStateProgram - (clearp) approval program.
     * @param creator - The address that created this application. This is the address where the
     * parameters and global state for this application can be found.
     * @param extraProgramPages - (epp) the amount of extra program pages available to this app.
     * @param globalState - (gs) global state
     * @param globalStateSchema - (gsch) global schema
     * @param localStateSchema - (lsch) local schema
     * @param version - (v) the number of updates to the application programs
     */
    constructor({ approvalProgram, clearStateProgram, creator, extraProgramPages, globalState, globalStateSchema, localStateSchema, version, }: {
        approvalProgram: string | Uint8Array;
        clearStateProgram: string | Uint8Array;
        creator: Address | string;
        extraProgramPages?: number | bigint;
        globalState?: TealKeyValue[];
        globalStateSchema?: ApplicationStateSchema;
        localStateSchema?: ApplicationStateSchema;
        version?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationParams;
}
/**
 * An operation against an application's global/local/box state.
 */
export declare class ApplicationStateOperation implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Type of application state. Value `g` is **global state**, `l` is **local
     * state**, `b` is **boxes**.
     */
    appStateType: string;
    /**
     * The key (name) of the global/local/box state.
     */
    key: Uint8Array;
    /**
     * Operation type. Value `w` is **write**, `d` is **delete**.
     */
    operation: string;
    /**
     * For local state changes, the address of the account associated with the local
     * state.
     */
    account?: Address;
    /**
     * Represents an AVM value.
     */
    newValue?: AvmValue;
    /**
     * Creates a new `ApplicationStateOperation` object.
     * @param appStateType - Type of application state. Value `g` is **global state**, `l` is **local
     * state**, `b` is **boxes**.
     * @param key - The key (name) of the global/local/box state.
     * @param operation - Operation type. Value `w` is **write**, `d` is **delete**.
     * @param account - For local state changes, the address of the account associated with the local
     * state.
     * @param newValue - Represents an AVM value.
     */
    constructor({ appStateType, key, operation, account, newValue, }: {
        appStateType: string;
        key: string | Uint8Array;
        operation: string;
        account?: Address | string;
        newValue?: AvmValue;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationStateOperation;
}
/**
 * Specifies maximums on the number of each type that may be stored.
 */
export declare class ApplicationStateSchema implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (nbs) num of byte slices.
     */
    numByteSlice: number;
    /**
     * (nui) num of uints.
     */
    numUint: number;
    /**
     * Creates a new `ApplicationStateSchema` object.
     * @param numByteSlice - (nbs) num of byte slices.
     * @param numUint - (nui) num of uints.
     */
    constructor({ numByteSlice, numUint, }: {
        numByteSlice: number | bigint;
        numUint: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationStateSchema;
}
/**
 * Specifies both the unique identifier and the parameters for an asset
 */
export declare class Asset implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * unique asset identifier
     */
    index: bigint;
    /**
     * AssetParams specifies the parameters for an asset.
     * (apar) when part of an AssetConfig transaction.
     * Definition:
     * data/transactions/asset.go : AssetParams
     */
    params: AssetParams;
    /**
     * Creates a new `Asset` object.
     * @param index - unique asset identifier
     * @param params - AssetParams specifies the parameters for an asset.
     * (apar) when part of an AssetConfig transaction.
     * Definition:
     * data/transactions/asset.go : AssetParams
     */
    constructor({ index, params, }: {
        index: number | bigint;
        params: AssetParams;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): Asset;
}
/**
 * Describes an asset held by an account.
 * Definition:
 * data/basics/userBalance.go : AssetHolding
 */
export declare class AssetHolding implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (a) number of units held.
     */
    amount: bigint;
    /**
     * Asset ID of the holding.
     */
    assetId: bigint;
    /**
     * (f) whether or not the holding is frozen.
     */
    isFrozen: boolean;
    /**
     * Creates a new `AssetHolding` object.
     * @param amount - (a) number of units held.
     * @param assetId - Asset ID of the holding.
     * @param isFrozen - (f) whether or not the holding is frozen.
     */
    constructor({ amount, assetId, isFrozen, }: {
        amount: number | bigint;
        assetId: number | bigint;
        isFrozen: boolean;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AssetHolding;
}
/**
 * References an asset held by an account.
 */
export declare class AssetHoldingReference implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Address of the account holding the asset.
     */
    account: Address;
    /**
     * Asset ID of the holding.
     */
    asset: bigint;
    /**
     * Creates a new `AssetHoldingReference` object.
     * @param account - Address of the account holding the asset.
     * @param asset - Asset ID of the holding.
     */
    constructor({ account, asset, }: {
        account: Address | string;
        asset: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AssetHoldingReference;
}
/**
 * AssetParams specifies the parameters for an asset.
 * (apar) when part of an AssetConfig transaction.
 * Definition:
 * data/transactions/asset.go : AssetParams
 */
export declare class AssetParams implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The address that created this asset. This is the address where the parameters
     * for this asset can be found, and also the address where unwanted asset units can
     * be sent in the worst case.
     */
    creator: string;
    /**
     * (dc) The number of digits to use after the decimal point when displaying this
     * asset. If 0, the asset is not divisible. If 1, the base unit of the asset is in
     * tenths. If 2, the base unit of the asset is in hundredths, and so on. This value
     * must be between 0 and 19 (inclusive).
     */
    decimals: number;
    /**
     * (t) The total number of units of this asset.
     */
    total: bigint;
    /**
     * (c) Address of account used to clawback holdings of this asset. If empty,
     * clawback is not permitted.
     */
    clawback?: string;
    /**
     * (df) Whether holdings of this asset are frozen by default.
     */
    defaultFrozen?: boolean;
    /**
     * (f) Address of account used to freeze holdings of this asset. If empty, freezing
     * is not permitted.
     */
    freeze?: string;
    /**
     * (m) Address of account used to manage the keys of this asset and to destroy it.
     */
    manager?: string;
    /**
     * (am) A commitment to some unspecified asset metadata. The format of this
     * metadata is up to the application.
     */
    metadataHash?: Uint8Array;
    /**
     * (an) Name of this asset, as supplied by the creator. Included only when the
     * asset name is composed of printable utf-8 characters.
     */
    name?: string;
    /**
     * Base64 encoded name of this asset, as supplied by the creator.
     */
    nameB64?: Uint8Array;
    /**
     * (r) Address of account holding reserve (non-minted) units of this asset.
     */
    reserve?: string;
    /**
     * (un) Name of a unit of this asset, as supplied by the creator. Included only
     * when the name of a unit of this asset is composed of printable utf-8 characters.
     */
    unitName?: string;
    /**
     * Base64 encoded name of a unit of this asset, as supplied by the creator.
     */
    unitNameB64?: Uint8Array;
    /**
     * (au) URL where more information about the asset can be retrieved. Included only
     * when the URL is composed of printable utf-8 characters.
     */
    url?: string;
    /**
     * Base64 encoded URL where more information about the asset can be retrieved.
     */
    urlB64?: Uint8Array;
    /**
     * Creates a new `AssetParams` object.
     * @param creator - The address that created this asset. This is the address where the parameters
     * for this asset can be found, and also the address where unwanted asset units can
     * be sent in the worst case.
     * @param decimals - (dc) The number of digits to use after the decimal point when displaying this
     * asset. If 0, the asset is not divisible. If 1, the base unit of the asset is in
     * tenths. If 2, the base unit of the asset is in hundredths, and so on. This value
     * must be between 0 and 19 (inclusive).
     * @param total - (t) The total number of units of this asset.
     * @param clawback - (c) Address of account used to clawback holdings of this asset. If empty,
     * clawback is not permitted.
     * @param defaultFrozen - (df) Whether holdings of this asset are frozen by default.
     * @param freeze - (f) Address of account used to freeze holdings of this asset. If empty, freezing
     * is not permitted.
     * @param manager - (m) Address of account used to manage the keys of this asset and to destroy it.
     * @param metadataHash - (am) A commitment to some unspecified asset metadata. The format of this
     * metadata is up to the application.
     * @param name - (an) Name of this asset, as supplied by the creator. Included only when the
     * asset name is composed of printable utf-8 characters.
     * @param nameB64 - Base64 encoded name of this asset, as supplied by the creator.
     * @param reserve - (r) Address of account holding reserve (non-minted) units of this asset.
     * @param unitName - (un) Name of a unit of this asset, as supplied by the creator. Included only
     * when the name of a unit of this asset is composed of printable utf-8 characters.
     * @param unitNameB64 - Base64 encoded name of a unit of this asset, as supplied by the creator.
     * @param url - (au) URL where more information about the asset can be retrieved. Included only
     * when the URL is composed of printable utf-8 characters.
     * @param urlB64 - Base64 encoded URL where more information about the asset can be retrieved.
     */
    constructor({ creator, decimals, total, clawback, defaultFrozen, freeze, manager, metadataHash, name, nameB64, reserve, unitName, unitNameB64, url, urlB64, }: {
        creator: string;
        decimals: number | bigint;
        total: number | bigint;
        clawback?: string;
        defaultFrozen?: boolean;
        freeze?: string;
        manager?: string;
        metadataHash?: string | Uint8Array;
        name?: string;
        nameB64?: string | Uint8Array;
        reserve?: string;
        unitName?: string;
        unitNameB64?: string | Uint8Array;
        url?: string;
        urlB64?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AssetParams;
}
/**
 * Represents an AVM key-value pair in an application store.
 */
export declare class AvmKeyValue implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    key: Uint8Array;
    /**
     * Represents an AVM value.
     */
    value: AvmValue;
    /**
     * Creates a new `AvmKeyValue` object.
     * @param key -
     * @param value - Represents an AVM value.
     */
    constructor({ key, value }: {
        key: string | Uint8Array;
        value: AvmValue;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AvmKeyValue;
}
/**
 * Represents an AVM value.
 */
export declare class AvmValue implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * value type. Value `1` refers to **bytes**, value `2` refers to **uint64**
     */
    type: number;
    /**
     * bytes value.
     */
    bytes?: Uint8Array;
    /**
     * uint value.
     */
    uint?: bigint;
    /**
     * Creates a new `AvmValue` object.
     * @param type - value type. Value `1` refers to **bytes**, value `2` refers to **uint64**
     * @param bytes - bytes value.
     * @param uint - uint value.
     */
    constructor({ type, bytes, uint, }: {
        type: number | bigint;
        bytes?: string | Uint8Array;
        uint?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AvmValue;
}
/**
 * Hash of a block header.
 */
export declare class BlockHashResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Block header hash.
     */
    blockhash: string;
    /**
     * Creates a new `BlockHashResponse` object.
     * @param blockhash - Block header hash.
     */
    constructor({ blockhash }: {
        blockhash: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BlockHashResponse;
}
/**
 * All logs emitted in the given round. Each app call, whether top-level or inner,
 * that contains logs results in a separate AppCallLogs object. Therefore there may
 * be multiple AppCallLogs with the same application ID and outer transaction ID in
 * the event of multiple inner app calls to the same app. App calls with no logs
 * are not included in the response. AppCallLogs are returned in the same order
 * that their corresponding app call appeared in the block (pre-order traversal of
 * inner app calls)
 */
export declare class BlockLogsResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    logs: AppCallLogs[];
    /**
     * Creates a new `BlockLogsResponse` object.
     * @param logs -
     */
    constructor({ logs }: {
        logs: AppCallLogs[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BlockLogsResponse;
}
/**
 * Encoded block object.
 */
export declare class BlockResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Block header data.
     */
    block: Block;
    /**
     * Optional certificate object. This is only included when the format is set to
     * message pack.
     */
    cert?: UntypedValue;
    /**
     * Creates a new `BlockResponse` object.
     * @param block - Block header data.
     * @param cert - Optional certificate object. This is only included when the format is set to
     * message pack.
     */
    constructor({ block, cert }: {
        block: Block;
        cert?: UntypedValue;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BlockResponse;
}
/**
 * Top level transaction IDs in a block.
 */
export declare class BlockTxidsResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Block transaction IDs.
     */
    blocktxids: string[];
    /**
     * Creates a new `BlockTxidsResponse` object.
     * @param blocktxids - Block transaction IDs.
     */
    constructor({ blocktxids }: {
        blocktxids: string[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BlockTxidsResponse;
}
/**
 * Box name and its content.
 */
export declare class Box implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The box name, base64 encoded
     */
    name: Uint8Array;
    /**
     * The round for which this information is relevant
     */
    round?: bigint;
    /**
     * The box value, base64 encoded.
     */
    value?: Uint8Array;
    /**
     * Creates a new `Box` object.
     * @param name - The box name, base64 encoded
     * @param round - The round for which this information is relevant
     * @param value - The box value, base64 encoded.
     */
    constructor({ name, round, value, }: {
        name: string | Uint8Array;
        round?: number | bigint;
        value?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): Box;
}
/**
 * References a box of an application.
 */
export declare class BoxReference implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Application ID which this box belongs to
     */
    app: bigint;
    /**
     * Base64 encoded box name
     */
    name: Uint8Array;
    /**
     * Creates a new `BoxReference` object.
     * @param app - Application ID which this box belongs to
     * @param name - Base64 encoded box name
     */
    constructor({ app, name, }: {
        app: number | bigint;
        name: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BoxReference;
}
/**
 * Boxes of an application
 */
export declare class BoxesResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    boxes: Box[];
    /**
     * The round for which this information is relevant.
     */
    round: number;
    /**
     * Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    nextToken?: string;
    /**
     * Creates a new `BoxesResponse` object.
     * @param boxes -
     * @param round - The round for which this information is relevant.
     * @param nextToken - Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    constructor({ boxes, round, nextToken, }: {
        boxes: Box[];
        round: number | bigint;
        nextToken?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BoxesResponse;
}
export declare class BuildVersion implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    branch: string;
    buildNumber: number;
    channel: string;
    commitHash: string;
    major: number;
    minor: number;
    /**
     * Creates a new `BuildVersion` object.
     * @param branch -
     * @param buildNumber -
     * @param channel -
     * @param commitHash -
     * @param major -
     * @param minor -
     */
    constructor({ branch, buildNumber, channel, commitHash, major, minor, }: {
        branch: string;
        buildNumber: number | bigint;
        channel: string;
        commitHash: string;
        major: number | bigint;
        minor: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BuildVersion;
}
/**
 * Teal compile Result
 */
export declare class CompileResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * base32 SHA512_256 of program bytes (Address style)
     */
    hash: string;
    /**
     * base64 encoded program bytes
     */
    result: string;
    /**
     * JSON of the source map
     */
    sourcemap?: UntypedValue;
    /**
     * Creates a new `CompileResponse` object.
     * @param hash - base32 SHA512_256 of program bytes (Address style)
     * @param result - base64 encoded program bytes
     * @param sourcemap - JSON of the source map
     */
    constructor({ hash, result, sourcemap, }: {
        hash: string;
        result: string;
        sourcemap?: UntypedValue;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): CompileResponse;
}
/**
 * Teal disassembly Result
 */
export declare class DisassembleResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * disassembled Teal code
     */
    result: string;
    /**
     * Creates a new `DisassembleResponse` object.
     * @param result - disassembled Teal code
     */
    constructor({ result }: {
        result: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): DisassembleResponse;
}
/**
 * Request data type for dryrun endpoint. Given the Transactions and simulated
 * ledger state upload, run TEAL scripts and return debugging information.
 */
export declare class DryrunRequest implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    accounts: Account[];
    apps: Application[];
    /**
     * LatestTimestamp is available to some TEAL scripts. Defaults to the latest
     * confirmed timestamp this algod is attached to.
     */
    latestTimestamp: number;
    /**
     * ProtocolVersion specifies a specific version string to operate under, otherwise
     * whatever the current protocol of the network this algod is running in.
     */
    protocolVersion: string;
    /**
     * Round is available to some TEAL scripts. Defaults to the current round on the
     * network this algod is attached to.
     */
    round: bigint;
    sources: DryrunSource[];
    txns: SignedTransaction[];
    /**
     * Creates a new `DryrunRequest` object.
     * @param accounts -
     * @param apps -
     * @param latestTimestamp - LatestTimestamp is available to some TEAL scripts. Defaults to the latest
     * confirmed timestamp this algod is attached to.
     * @param protocolVersion - ProtocolVersion specifies a specific version string to operate under, otherwise
     * whatever the current protocol of the network this algod is running in.
     * @param round - Round is available to some TEAL scripts. Defaults to the current round on the
     * network this algod is attached to.
     * @param sources -
     * @param txns -
     */
    constructor({ accounts, apps, latestTimestamp, protocolVersion, round, sources, txns, }: {
        accounts: Account[];
        apps: Application[];
        latestTimestamp: number | bigint;
        protocolVersion: string;
        round: number | bigint;
        sources: DryrunSource[];
        txns: SignedTransaction[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): DryrunRequest;
}
/**
 * DryrunResponse contains per-txn debug information from a dryrun.
 */
export declare class DryrunResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    error: string;
    /**
     * Protocol version is the protocol version Dryrun was operated under.
     */
    protocolVersion: string;
    txns: DryrunTxnResult[];
    /**
     * Creates a new `DryrunResponse` object.
     * @param error -
     * @param protocolVersion - Protocol version is the protocol version Dryrun was operated under.
     * @param txns -
     */
    constructor({ error, protocolVersion, txns, }: {
        error: string;
        protocolVersion: string;
        txns: DryrunTxnResult[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): DryrunResponse;
}
/**
 * DryrunSource is TEAL source text that gets uploaded, compiled, and inserted into
 * transactions or application state.
 */
export declare class DryrunSource implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    appIndex: bigint;
    /**
     * FieldName is what kind of sources this is. If lsig then it goes into the
     * transactions[this.TxnIndex].LogicSig. If approv or clearp it goes into the
     * Approval Program or Clear State Program of application[this.AppIndex].
     */
    fieldName: string;
    source: string;
    txnIndex: number;
    /**
     * Creates a new `DryrunSource` object.
     * @param appIndex -
     * @param fieldName - FieldName is what kind of sources this is. If lsig then it goes into the
     * transactions[this.TxnIndex].LogicSig. If approv or clearp it goes into the
     * Approval Program or Clear State Program of application[this.AppIndex].
     * @param source -
     * @param txnIndex -
     */
    constructor({ appIndex, fieldName, source, txnIndex, }: {
        appIndex: number | bigint;
        fieldName: string;
        source: string;
        txnIndex: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): DryrunSource;
}
/**
 * Stores the TEAL eval step data
 */
export declare class DryrunState implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Line number
     */
    line: number;
    /**
     * Program counter
     */
    pc: number;
    stack: TealValue[];
    /**
     * Evaluation error if any
     */
    error?: string;
    scratch?: TealValue[];
    /**
     * Creates a new `DryrunState` object.
     * @param line - Line number
     * @param pc - Program counter
     * @param stack -
     * @param error - Evaluation error if any
     * @param scratch -
     */
    constructor({ line, pc, stack, error, scratch, }: {
        line: number | bigint;
        pc: number | bigint;
        stack: TealValue[];
        error?: string;
        scratch?: TealValue[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): DryrunState;
}
/**
 * DryrunTxnResult contains any LogicSig or ApplicationCall program debug
 * information and state updates from a dryrun.
 */
export declare class DryrunTxnResult implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Disassembled program line by line.
     */
    disassembly: string[];
    appCallMessages?: string[];
    appCallTrace?: DryrunState[];
    /**
     * Budget added during execution of app call transaction.
     */
    budgetAdded?: number;
    /**
     * Budget consumed during execution of app call transaction.
     */
    budgetConsumed?: number;
    /**
     * Application state delta.
     */
    globalDelta?: EvalDeltaKeyValue[];
    localDeltas?: AccountStateDelta[];
    /**
     * Disassembled lsig program line by line.
     */
    logicSigDisassembly?: string[];
    logicSigMessages?: string[];
    logicSigTrace?: DryrunState[];
    logs?: Uint8Array[];
    /**
     * Creates a new `DryrunTxnResult` object.
     * @param disassembly - Disassembled program line by line.
     * @param appCallMessages -
     * @param appCallTrace -
     * @param budgetAdded - Budget added during execution of app call transaction.
     * @param budgetConsumed - Budget consumed during execution of app call transaction.
     * @param globalDelta - Application state delta.
     * @param localDeltas -
     * @param logicSigDisassembly - Disassembled lsig program line by line.
     * @param logicSigMessages -
     * @param logicSigTrace -
     * @param logs -
     */
    constructor({ disassembly, appCallMessages, appCallTrace, budgetAdded, budgetConsumed, globalDelta, localDeltas, logicSigDisassembly, logicSigMessages, logicSigTrace, logs, }: {
        disassembly: string[];
        appCallMessages?: string[];
        appCallTrace?: DryrunState[];
        budgetAdded?: number | bigint;
        budgetConsumed?: number | bigint;
        globalDelta?: EvalDeltaKeyValue[];
        localDeltas?: AccountStateDelta[];
        logicSigDisassembly?: string[];
        logicSigMessages?: string[];
        logicSigTrace?: DryrunState[];
        logs?: Uint8Array[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): DryrunTxnResult;
}
/**
 * An error response with optional data field.
 */
export declare class ErrorResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    message: string;
    data?: UntypedValue;
    /**
     * Creates a new `ErrorResponse` object.
     * @param message -
     * @param data -
     */
    constructor({ message, data }: {
        message: string;
        data?: UntypedValue;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ErrorResponse;
}
/**
 * Represents a TEAL value delta.
 */
export declare class EvalDelta implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (at) delta action.
     */
    action: number;
    /**
     * (bs) bytes value.
     */
    bytes?: string;
    /**
     * (ui) uint value.
     */
    uint?: bigint;
    /**
     * Creates a new `EvalDelta` object.
     * @param action - (at) delta action.
     * @param bytes - (bs) bytes value.
     * @param uint - (ui) uint value.
     */
    constructor({ action, bytes, uint, }: {
        action: number | bigint;
        bytes?: string;
        uint?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): EvalDelta;
}
/**
 * Key-value pairs for StateDelta.
 */
export declare class EvalDeltaKeyValue implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    key: string;
    /**
     * Represents a TEAL value delta.
     */
    value: EvalDelta;
    /**
     * Creates a new `EvalDeltaKeyValue` object.
     * @param key -
     * @param value - Represents a TEAL value delta.
     */
    constructor({ key, value }: {
        key: string;
        value: EvalDelta;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): EvalDeltaKeyValue;
}
export declare class Genesis implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    alloc: GenesisAllocation[];
    fees: string;
    id: string;
    network: string;
    proto: string;
    rwd: string;
    timestamp: number;
    comment?: string;
    devmode?: boolean;
    /**
     * Creates a new `Genesis` object.
     * @param alloc -
     * @param fees -
     * @param id -
     * @param network -
     * @param proto -
     * @param rwd -
     * @param timestamp -
     * @param comment -
     * @param devmode -
     */
    constructor({ alloc, fees, id, network, proto, rwd, timestamp, comment, devmode, }: {
        alloc: GenesisAllocation[];
        fees: string;
        id: string;
        network: string;
        proto: string;
        rwd: string;
        timestamp: number | bigint;
        comment?: string;
        devmode?: boolean;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): Genesis;
}
export declare class GenesisAllocation implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    addr: string;
    comment: string;
    state: UntypedValue;
    /**
     * Creates a new `GenesisAllocation` object.
     * @param addr -
     * @param comment -
     * @param state -
     */
    constructor({ addr, comment, state, }: {
        addr: string;
        comment: string;
        state: UntypedValue;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): GenesisAllocation;
}
/**
 * Response containing the timestamp offset in seconds
 */
export declare class GetBlockTimeStampOffsetResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Timestamp offset in seconds.
     */
    offset: number;
    /**
     * Creates a new `GetBlockTimeStampOffsetResponse` object.
     * @param offset - Timestamp offset in seconds.
     */
    constructor({ offset }: {
        offset: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): GetBlockTimeStampOffsetResponse;
}
/**
 * Response containing the ledger's minimum sync round
 */
export declare class GetSyncRoundResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The minimum sync round for the ledger.
     */
    round: bigint;
    /**
     * Creates a new `GetSyncRoundResponse` object.
     * @param round - The minimum sync round for the ledger.
     */
    constructor({ round }: {
        round: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): GetSyncRoundResponse;
}
/**
 * Contains a ledger delta for a single transaction group
 */
export declare class LedgerStateDeltaForTransactionGroup implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Ledger StateDelta object
     */
    delta: LedgerStateDelta;
    ids: string[];
    /**
     * Creates a new `LedgerStateDeltaForTransactionGroup` object.
     * @param delta - Ledger StateDelta object
     * @param ids -
     */
    constructor({ delta, ids }: {
        delta: LedgerStateDelta;
        ids: string[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): LedgerStateDeltaForTransactionGroup;
}
/**
 * Proof of membership and position of a light block header.
 */
export declare class LightBlockHeaderProof implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The index of the light block header in the vector commitment tree
     */
    index: number;
    /**
     * The encoded proof.
     */
    proof: Uint8Array;
    /**
     * Represents the depth of the tree that is being proven, i.e. the number of edges
     * from a leaf to the root.
     */
    treedepth: number;
    /**
     * Creates a new `LightBlockHeaderProof` object.
     * @param index - The index of the light block header in the vector commitment tree
     * @param proof - The encoded proof.
     * @param treedepth - Represents the depth of the tree that is being proven, i.e. the number of edges
     * from a leaf to the root.
     */
    constructor({ index, proof, treedepth, }: {
        index: number | bigint;
        proof: string | Uint8Array;
        treedepth: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): LightBlockHeaderProof;
}
/**
 *
 */
export declare class NodeStatusResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * CatchupTime in nanoseconds
     */
    catchupTime: bigint;
    /**
     * LastRound indicates the last round seen
     */
    lastRound: bigint;
    /**
     * LastVersion indicates the last consensus version supported
     */
    lastVersion: string;
    /**
     * NextVersion of consensus protocol to use
     */
    nextVersion: string;
    /**
     * NextVersionRound is the round at which the next consensus version will apply
     */
    nextVersionRound: bigint;
    /**
     * NextVersionSupported indicates whether the next consensus version is supported
     * by this node
     */
    nextVersionSupported: boolean;
    /**
     * StoppedAtUnsupportedRound indicates that the node does not support the new
     * rounds and has stopped making progress
     */
    stoppedAtUnsupportedRound: boolean;
    /**
     * TimeSinceLastRound in nanoseconds
     */
    timeSinceLastRound: bigint;
    /**
     * The current catchpoint that is being caught up to
     */
    catchpoint?: string;
    /**
     * The number of blocks that have already been obtained by the node as part of the
     * catchup
     */
    catchpointAcquiredBlocks?: number;
    /**
     * The number of accounts from the current catchpoint that have been processed so
     * far as part of the catchup
     */
    catchpointProcessedAccounts?: number;
    /**
     * The number of key-values (KVs) from the current catchpoint that have been
     * processed so far as part of the catchup
     */
    catchpointProcessedKvs?: number;
    /**
     * The total number of accounts included in the current catchpoint
     */
    catchpointTotalAccounts?: number;
    /**
     * The total number of blocks that are required to complete the current catchpoint
     * catchup
     */
    catchpointTotalBlocks?: number;
    /**
     * The total number of key-values (KVs) included in the current catchpoint
     */
    catchpointTotalKvs?: number;
    /**
     * The number of accounts from the current catchpoint that have been verified so
     * far as part of the catchup
     */
    catchpointVerifiedAccounts?: number;
    /**
     * The number of key-values (KVs) from the current catchpoint that have been
     * verified so far as part of the catchup
     */
    catchpointVerifiedKvs?: number;
    /**
     * The last catchpoint seen by the node
     */
    lastCatchpoint?: string;
    /**
     * Upgrade delay
     */
    upgradeDelay?: bigint;
    /**
     * Next protocol round
     */
    upgradeNextProtocolVoteBefore?: bigint;
    /**
     * No votes cast for consensus upgrade
     */
    upgradeNoVotes?: number;
    /**
     * This node's upgrade vote
     */
    upgradeNodeVote?: boolean;
    /**
     * Total voting rounds for current upgrade
     */
    upgradeVoteRounds?: number;
    /**
     * Total votes cast for consensus upgrade
     */
    upgradeVotes?: number;
    /**
     * Yes votes required for consensus upgrade
     */
    upgradeVotesRequired?: number;
    /**
     * Yes votes cast for consensus upgrade
     */
    upgradeYesVotes?: number;
    /**
     * Creates a new `NodeStatusResponse` object.
     * @param catchupTime - CatchupTime in nanoseconds
     * @param lastRound - LastRound indicates the last round seen
     * @param lastVersion - LastVersion indicates the last consensus version supported
     * @param nextVersion - NextVersion of consensus protocol to use
     * @param nextVersionRound - NextVersionRound is the round at which the next consensus version will apply
     * @param nextVersionSupported - NextVersionSupported indicates whether the next consensus version is supported
     * by this node
     * @param stoppedAtUnsupportedRound - StoppedAtUnsupportedRound indicates that the node does not support the new
     * rounds and has stopped making progress
     * @param timeSinceLastRound - TimeSinceLastRound in nanoseconds
     * @param catchpoint - The current catchpoint that is being caught up to
     * @param catchpointAcquiredBlocks - The number of blocks that have already been obtained by the node as part of the
     * catchup
     * @param catchpointProcessedAccounts - The number of accounts from the current catchpoint that have been processed so
     * far as part of the catchup
     * @param catchpointProcessedKvs - The number of key-values (KVs) from the current catchpoint that have been
     * processed so far as part of the catchup
     * @param catchpointTotalAccounts - The total number of accounts included in the current catchpoint
     * @param catchpointTotalBlocks - The total number of blocks that are required to complete the current catchpoint
     * catchup
     * @param catchpointTotalKvs - The total number of key-values (KVs) included in the current catchpoint
     * @param catchpointVerifiedAccounts - The number of accounts from the current catchpoint that have been verified so
     * far as part of the catchup
     * @param catchpointVerifiedKvs - The number of key-values (KVs) from the current catchpoint that have been
     * verified so far as part of the catchup
     * @param lastCatchpoint - The last catchpoint seen by the node
     * @param upgradeDelay - Upgrade delay
     * @param upgradeNextProtocolVoteBefore - Next protocol round
     * @param upgradeNoVotes - No votes cast for consensus upgrade
     * @param upgradeNodeVote - This node's upgrade vote
     * @param upgradeVoteRounds - Total voting rounds for current upgrade
     * @param upgradeVotes - Total votes cast for consensus upgrade
     * @param upgradeVotesRequired - Yes votes required for consensus upgrade
     * @param upgradeYesVotes - Yes votes cast for consensus upgrade
     */
    constructor({ catchupTime, lastRound, lastVersion, nextVersion, nextVersionRound, nextVersionSupported, stoppedAtUnsupportedRound, timeSinceLastRound, catchpoint, catchpointAcquiredBlocks, catchpointProcessedAccounts, catchpointProcessedKvs, catchpointTotalAccounts, catchpointTotalBlocks, catchpointTotalKvs, catchpointVerifiedAccounts, catchpointVerifiedKvs, lastCatchpoint, upgradeDelay, upgradeNextProtocolVoteBefore, upgradeNoVotes, upgradeNodeVote, upgradeVoteRounds, upgradeVotes, upgradeVotesRequired, upgradeYesVotes, }: {
        catchupTime: number | bigint;
        lastRound: number | bigint;
        lastVersion: string;
        nextVersion: string;
        nextVersionRound: number | bigint;
        nextVersionSupported: boolean;
        stoppedAtUnsupportedRound: boolean;
        timeSinceLastRound: number | bigint;
        catchpoint?: string;
        catchpointAcquiredBlocks?: number | bigint;
        catchpointProcessedAccounts?: number | bigint;
        catchpointProcessedKvs?: number | bigint;
        catchpointTotalAccounts?: number | bigint;
        catchpointTotalBlocks?: number | bigint;
        catchpointTotalKvs?: number | bigint;
        catchpointVerifiedAccounts?: number | bigint;
        catchpointVerifiedKvs?: number | bigint;
        lastCatchpoint?: string;
        upgradeDelay?: number | bigint;
        upgradeNextProtocolVoteBefore?: number | bigint;
        upgradeNoVotes?: number | bigint;
        upgradeNodeVote?: boolean;
        upgradeVoteRounds?: number | bigint;
        upgradeVotes?: number | bigint;
        upgradeVotesRequired?: number | bigint;
        upgradeYesVotes?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): NodeStatusResponse;
}
/**
 * Details about a pending transaction. If the transaction was recently confirmed,
 * includes confirmation details like the round and reward details.
 */
export declare class PendingTransactionResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Indicates that the transaction was kicked out of this node's transaction pool
     * (and specifies why that happened). An empty string indicates the transaction
     * wasn't kicked out of this node's txpool due to an error.
     */
    poolError: string;
    /**
     * The raw signed transaction.
     */
    txn: SignedTransaction;
    /**
     * The application index if the transaction was found and it created an
     * application.
     */
    applicationIndex?: bigint;
    /**
     * The number of the asset's unit that were transferred to the close-to address.
     */
    assetClosingAmount?: bigint;
    /**
     * The asset index if the transaction was found and it created an asset.
     */
    assetIndex?: bigint;
    /**
     * Rewards in microalgos applied to the close remainder to account.
     */
    closeRewards?: bigint;
    /**
     * Closing amount for the transaction.
     */
    closingAmount?: bigint;
    /**
     * The round where this transaction was confirmed, if present.
     */
    confirmedRound?: bigint;
    /**
     * Global state key/value changes for the application being executed by this
     * transaction.
     */
    globalStateDelta?: EvalDeltaKeyValue[];
    /**
     * Inner transactions produced by application execution.
     */
    innerTxns?: PendingTransactionResponse[];
    /**
     * Local state key/value changes for the application being executed by this
     * transaction.
     */
    localStateDelta?: AccountStateDelta[];
    /**
     * Logs for the application being executed by this transaction.
     */
    logs?: Uint8Array[];
    /**
     * Rewards in microalgos applied to the receiver account.
     */
    receiverRewards?: bigint;
    /**
     * Rewards in microalgos applied to the sender account.
     */
    senderRewards?: bigint;
    /**
     * Creates a new `PendingTransactionResponse` object.
     * @param poolError - Indicates that the transaction was kicked out of this node's transaction pool
     * (and specifies why that happened). An empty string indicates the transaction
     * wasn't kicked out of this node's txpool due to an error.
     * @param txn - The raw signed transaction.
     * @param applicationIndex - The application index if the transaction was found and it created an
     * application.
     * @param assetClosingAmount - The number of the asset's unit that were transferred to the close-to address.
     * @param assetIndex - The asset index if the transaction was found and it created an asset.
     * @param closeRewards - Rewards in microalgos applied to the close remainder to account.
     * @param closingAmount - Closing amount for the transaction.
     * @param confirmedRound - The round where this transaction was confirmed, if present.
     * @param globalStateDelta - Global state key/value changes for the application being executed by this
     * transaction.
     * @param innerTxns - Inner transactions produced by application execution.
     * @param localStateDelta - Local state key/value changes for the application being executed by this
     * transaction.
     * @param logs - Logs for the application being executed by this transaction.
     * @param receiverRewards - Rewards in microalgos applied to the receiver account.
     * @param senderRewards - Rewards in microalgos applied to the sender account.
     */
    constructor({ poolError, txn, applicationIndex, assetClosingAmount, assetIndex, closeRewards, closingAmount, confirmedRound, globalStateDelta, innerTxns, localStateDelta, logs, receiverRewards, senderRewards, }: {
        poolError: string;
        txn: SignedTransaction;
        applicationIndex?: number | bigint;
        assetClosingAmount?: number | bigint;
        assetIndex?: number | bigint;
        closeRewards?: number | bigint;
        closingAmount?: number | bigint;
        confirmedRound?: number | bigint;
        globalStateDelta?: EvalDeltaKeyValue[];
        innerTxns?: PendingTransactionResponse[];
        localStateDelta?: AccountStateDelta[];
        logs?: Uint8Array[];
        receiverRewards?: number | bigint;
        senderRewards?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): PendingTransactionResponse;
}
/**
 * A potentially truncated list of transactions currently in the node's transaction
 * pool. You can compute whether or not the list is truncated if the number of
 * elements in the **top-transactions** array is fewer than **total-transactions**.
 */
export declare class PendingTransactionsResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * An array of signed transaction objects.
     */
    topTransactions: SignedTransaction[];
    /**
     * Total number of transactions in the pool.
     */
    totalTransactions: number;
    /**
     * Creates a new `PendingTransactionsResponse` object.
     * @param topTransactions - An array of signed transaction objects.
     * @param totalTransactions - Total number of transactions in the pool.
     */
    constructor({ topTransactions, totalTransactions, }: {
        topTransactions: SignedTransaction[];
        totalTransactions: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): PendingTransactionsResponse;
}
/**
 * Transaction ID of the submission.
 */
export declare class PostTransactionsResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * encoding of the transaction hash.
     */
    txid: string;
    /**
     * Creates a new `PostTransactionsResponse` object.
     * @param txid - encoding of the transaction hash.
     */
    constructor({ txid }: {
        txid: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): PostTransactionsResponse;
}
/**
 * A write operation into a scratch slot.
 */
export declare class ScratchChange implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Represents an AVM value.
     */
    newValue: AvmValue;
    /**
     * The scratch slot written.
     */
    slot: number;
    /**
     * Creates a new `ScratchChange` object.
     * @param newValue - Represents an AVM value.
     * @param slot - The scratch slot written.
     */
    constructor({ newValue, slot, }: {
        newValue: AvmValue;
        slot: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ScratchChange;
}
/**
 * Initial states of resources that were accessed during simulation.
 */
export declare class SimulateInitialStates implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The initial states of accessed application before simulation. The order of this
     * array is arbitrary.
     */
    appInitialStates?: ApplicationInitialStates[];
    /**
     * Creates a new `SimulateInitialStates` object.
     * @param appInitialStates - The initial states of accessed application before simulation. The order of this
     * array is arbitrary.
     */
    constructor({ appInitialStates, }: {
        appInitialStates?: ApplicationInitialStates[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): SimulateInitialStates;
}
/**
 * Request type for simulation endpoint.
 */
export declare class SimulateRequest implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The transaction groups to simulate.
     */
    txnGroups: SimulateRequestTransactionGroup[];
    /**
     * Allows transactions without signatures to be simulated as if they had correct
     * signatures.
     */
    allowEmptySignatures?: boolean;
    /**
     * Lifts limits on log opcode usage during simulation.
     */
    allowMoreLogging?: boolean;
    /**
     * Allows access to unnamed resources during simulation.
     */
    allowUnnamedResources?: boolean;
    /**
     * An object that configures simulation execution trace.
     */
    execTraceConfig?: SimulateTraceConfig;
    /**
     * Applies extra opcode budget during simulation for each transaction group.
     */
    extraOpcodeBudget?: number;
    /**
     * If true, signers for transactions that are missing signatures will be fixed
     * during evaluation.
     */
    fixSigners?: boolean;
    /**
     * If provided, specifies the round preceding the simulation. State changes through
     * this round will be used to run this simulation. Usually only the 4 most recent
     * rounds will be available (controlled by the node config value MaxAcctLookback).
     * If not specified, defaults to the latest available round.
     */
    round?: bigint;
    /**
     * Creates a new `SimulateRequest` object.
     * @param txnGroups - The transaction groups to simulate.
     * @param allowEmptySignatures - Allows transactions without signatures to be simulated as if they had correct
     * signatures.
     * @param allowMoreLogging - Lifts limits on log opcode usage during simulation.
     * @param allowUnnamedResources - Allows access to unnamed resources during simulation.
     * @param execTraceConfig - An object that configures simulation execution trace.
     * @param extraOpcodeBudget - Applies extra opcode budget during simulation for each transaction group.
     * @param fixSigners - If true, signers for transactions that are missing signatures will be fixed
     * during evaluation.
     * @param round - If provided, specifies the round preceding the simulation. State changes through
     * this round will be used to run this simulation. Usually only the 4 most recent
     * rounds will be available (controlled by the node config value MaxAcctLookback).
     * If not specified, defaults to the latest available round.
     */
    constructor({ txnGroups, allowEmptySignatures, allowMoreLogging, allowUnnamedResources, execTraceConfig, extraOpcodeBudget, fixSigners, round, }: {
        txnGroups: SimulateRequestTransactionGroup[];
        allowEmptySignatures?: boolean;
        allowMoreLogging?: boolean;
        allowUnnamedResources?: boolean;
        execTraceConfig?: SimulateTraceConfig;
        extraOpcodeBudget?: number | bigint;
        fixSigners?: boolean;
        round?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): SimulateRequest;
}
/**
 * A transaction group to simulate.
 */
export declare class SimulateRequestTransactionGroup implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * An atomic transaction group.
     */
    txns: SignedTransaction[];
    /**
     * Creates a new `SimulateRequestTransactionGroup` object.
     * @param txns - An atomic transaction group.
     */
    constructor({ txns }: {
        txns: SignedTransaction[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): SimulateRequestTransactionGroup;
}
/**
 * Result of a transaction group simulation.
 */
export declare class SimulateResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The round immediately preceding this simulation. State changes through this
     * round were used to run this simulation.
     */
    lastRound: bigint;
    /**
     * A result object for each transaction group that was simulated.
     */
    txnGroups: SimulateTransactionGroupResult[];
    /**
     * The version of this response object.
     */
    version: number;
    /**
     * The set of parameters and limits override during simulation. If this set of
     * parameters is present, then evaluation parameters may differ from standard
     * evaluation in certain ways.
     */
    evalOverrides?: SimulationEvalOverrides;
    /**
     * An object that configures simulation execution trace.
     */
    execTraceConfig?: SimulateTraceConfig;
    /**
     * Initial states of resources that were accessed during simulation.
     */
    initialStates?: SimulateInitialStates;
    /**
     * Creates a new `SimulateResponse` object.
     * @param lastRound - The round immediately preceding this simulation. State changes through this
     * round were used to run this simulation.
     * @param txnGroups - A result object for each transaction group that was simulated.
     * @param version - The version of this response object.
     * @param evalOverrides - The set of parameters and limits override during simulation. If this set of
     * parameters is present, then evaluation parameters may differ from standard
     * evaluation in certain ways.
     * @param execTraceConfig - An object that configures simulation execution trace.
     * @param initialStates - Initial states of resources that were accessed during simulation.
     */
    constructor({ lastRound, txnGroups, version, evalOverrides, execTraceConfig, initialStates, }: {
        lastRound: number | bigint;
        txnGroups: SimulateTransactionGroupResult[];
        version: number | bigint;
        evalOverrides?: SimulationEvalOverrides;
        execTraceConfig?: SimulateTraceConfig;
        initialStates?: SimulateInitialStates;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): SimulateResponse;
}
/**
 * An object that configures simulation execution trace.
 */
export declare class SimulateTraceConfig implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * A boolean option for opting in execution trace features simulation endpoint.
     */
    enable?: boolean;
    /**
     * A boolean option enabling returning scratch slot changes together with execution
     * trace during simulation.
     */
    scratchChange?: boolean;
    /**
     * A boolean option enabling returning stack changes together with execution trace
     * during simulation.
     */
    stackChange?: boolean;
    /**
     * A boolean option enabling returning application state changes (global, local,
     * and box changes) with the execution trace during simulation.
     */
    stateChange?: boolean;
    /**
     * Creates a new `SimulateTraceConfig` object.
     * @param enable - A boolean option for opting in execution trace features simulation endpoint.
     * @param scratchChange - A boolean option enabling returning scratch slot changes together with execution
     * trace during simulation.
     * @param stackChange - A boolean option enabling returning stack changes together with execution trace
     * during simulation.
     * @param stateChange - A boolean option enabling returning application state changes (global, local,
     * and box changes) with the execution trace during simulation.
     */
    constructor({ enable, scratchChange, stackChange, stateChange, }: {
        enable?: boolean;
        scratchChange?: boolean;
        stackChange?: boolean;
        stateChange?: boolean;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): SimulateTraceConfig;
}
/**
 * Simulation result for an atomic transaction group
 */
export declare class SimulateTransactionGroupResult implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Simulation result for individual transactions
     */
    txnResults: SimulateTransactionResult[];
    /**
     * Total budget added during execution of app calls in the transaction group.
     */
    appBudgetAdded?: number;
    /**
     * Total budget consumed during execution of app calls in the transaction group.
     */
    appBudgetConsumed?: number;
    /**
     * If present, indicates which transaction in this group caused the failure. This
     * array represents the path to the failing transaction. Indexes are zero based,
     * the first element indicates the top-level transaction, and successive elements
     * indicate deeper inner transactions.
     */
    failedAt?: number[];
    /**
     * If present, indicates that the transaction group failed and specifies why that
     * happened
     */
    failureMessage?: string;
    /**
     * These are resources that were accessed by this group that would normally have
     * caused failure, but were allowed in simulation. Depending on where this object
     * is in the response, the unnamed resources it contains may or may not qualify for
     * group resource sharing. If this is a field in SimulateTransactionGroupResult,
     * the resources do qualify, but if this is a field in SimulateTransactionResult,
     * they do not qualify. In order to make this group valid for actual submission,
     * resources that qualify for group sharing can be made available by any
     * transaction of the group; otherwise, resources must be placed in the same
     * transaction which accessed them.
     */
    unnamedResourcesAccessed?: SimulateUnnamedResourcesAccessed;
    /**
     * Creates a new `SimulateTransactionGroupResult` object.
     * @param txnResults - Simulation result for individual transactions
     * @param appBudgetAdded - Total budget added during execution of app calls in the transaction group.
     * @param appBudgetConsumed - Total budget consumed during execution of app calls in the transaction group.
     * @param failedAt - If present, indicates which transaction in this group caused the failure. This
     * array represents the path to the failing transaction. Indexes are zero based,
     * the first element indicates the top-level transaction, and successive elements
     * indicate deeper inner transactions.
     * @param failureMessage - If present, indicates that the transaction group failed and specifies why that
     * happened
     * @param unnamedResourcesAccessed - These are resources that were accessed by this group that would normally have
     * caused failure, but were allowed in simulation. Depending on where this object
     * is in the response, the unnamed resources it contains may or may not qualify for
     * group resource sharing. If this is a field in SimulateTransactionGroupResult,
     * the resources do qualify, but if this is a field in SimulateTransactionResult,
     * they do not qualify. In order to make this group valid for actual submission,
     * resources that qualify for group sharing can be made available by any
     * transaction of the group; otherwise, resources must be placed in the same
     * transaction which accessed them.
     */
    constructor({ txnResults, appBudgetAdded, appBudgetConsumed, failedAt, failureMessage, unnamedResourcesAccessed, }: {
        txnResults: SimulateTransactionResult[];
        appBudgetAdded?: number | bigint;
        appBudgetConsumed?: number | bigint;
        failedAt?: (number | bigint)[];
        failureMessage?: string;
        unnamedResourcesAccessed?: SimulateUnnamedResourcesAccessed;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): SimulateTransactionGroupResult;
}
/**
 * Simulation result for an individual transaction
 */
export declare class SimulateTransactionResult implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Details about a pending transaction. If the transaction was recently confirmed,
     * includes confirmation details like the round and reward details.
     */
    txnResult: PendingTransactionResponse;
    /**
     * Budget used during execution of an app call transaction. This value includes
     * budged used by inner app calls spawned by this transaction.
     */
    appBudgetConsumed?: number;
    /**
     * The execution trace of calling an app or a logic sig, containing the inner app
     * call trace in a recursive way.
     */
    execTrace?: SimulationTransactionExecTrace;
    /**
     * The account that needed to sign this transaction when no signature was provided
     * and the provided signer was incorrect.
     */
    fixedSigner?: Address;
    /**
     * Budget used during execution of a logic sig transaction.
     */
    logicSigBudgetConsumed?: number;
    /**
     * These are resources that were accessed by this group that would normally have
     * caused failure, but were allowed in simulation. Depending on where this object
     * is in the response, the unnamed resources it contains may or may not qualify for
     * group resource sharing. If this is a field in SimulateTransactionGroupResult,
     * the resources do qualify, but if this is a field in SimulateTransactionResult,
     * they do not qualify. In order to make this group valid for actual submission,
     * resources that qualify for group sharing can be made available by any
     * transaction of the group; otherwise, resources must be placed in the same
     * transaction which accessed them.
     */
    unnamedResourcesAccessed?: SimulateUnnamedResourcesAccessed;
    /**
     * Creates a new `SimulateTransactionResult` object.
     * @param txnResult - Details about a pending transaction. If the transaction was recently confirmed,
     * includes confirmation details like the round and reward details.
     * @param appBudgetConsumed - Budget used during execution of an app call transaction. This value includes
     * budged used by inner app calls spawned by this transaction.
     * @param execTrace - The execution trace of calling an app or a logic sig, containing the inner app
     * call trace in a recursive way.
     * @param fixedSigner - The account that needed to sign this transaction when no signature was provided
     * and the provided signer was incorrect.
     * @param logicSigBudgetConsumed - Budget used during execution of a logic sig transaction.
     * @param unnamedResourcesAccessed - These are resources that were accessed by this group that would normally have
     * caused failure, but were allowed in simulation. Depending on where this object
     * is in the response, the unnamed resources it contains may or may not qualify for
     * group resource sharing. If this is a field in SimulateTransactionGroupResult,
     * the resources do qualify, but if this is a field in SimulateTransactionResult,
     * they do not qualify. In order to make this group valid for actual submission,
     * resources that qualify for group sharing can be made available by any
     * transaction of the group; otherwise, resources must be placed in the same
     * transaction which accessed them.
     */
    constructor({ txnResult, appBudgetConsumed, execTrace, fixedSigner, logicSigBudgetConsumed, unnamedResourcesAccessed, }: {
        txnResult: PendingTransactionResponse;
        appBudgetConsumed?: number | bigint;
        execTrace?: SimulationTransactionExecTrace;
        fixedSigner?: Address | string;
        logicSigBudgetConsumed?: number | bigint;
        unnamedResourcesAccessed?: SimulateUnnamedResourcesAccessed;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): SimulateTransactionResult;
}
/**
 * These are resources that were accessed by this group that would normally have
 * caused failure, but were allowed in simulation. Depending on where this object
 * is in the response, the unnamed resources it contains may or may not qualify for
 * group resource sharing. If this is a field in SimulateTransactionGroupResult,
 * the resources do qualify, but if this is a field in SimulateTransactionResult,
 * they do not qualify. In order to make this group valid for actual submission,
 * resources that qualify for group sharing can be made available by any
 * transaction of the group; otherwise, resources must be placed in the same
 * transaction which accessed them.
 */
export declare class SimulateUnnamedResourcesAccessed implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The unnamed accounts that were referenced. The order of this array is arbitrary.
     */
    accounts?: Address[];
    /**
     * The unnamed application local states that were referenced. The order of this
     * array is arbitrary.
     */
    appLocals?: ApplicationLocalReference[];
    /**
     * The unnamed applications that were referenced. The order of this array is
     * arbitrary.
     */
    apps?: bigint[];
    /**
     * The unnamed asset holdings that were referenced. The order of this array is
     * arbitrary.
     */
    assetHoldings?: AssetHoldingReference[];
    /**
     * The unnamed assets that were referenced. The order of this array is arbitrary.
     */
    assets?: bigint[];
    /**
     * The unnamed boxes that were referenced. The order of this array is arbitrary.
     */
    boxes?: BoxReference[];
    /**
     * The number of extra box references used to increase the IO budget. This is in
     * addition to the references defined in the input transaction group and any
     * referenced to unnamed boxes.
     */
    extraBoxRefs?: number;
    /**
     * Creates a new `SimulateUnnamedResourcesAccessed` object.
     * @param accounts - The unnamed accounts that were referenced. The order of this array is arbitrary.
     * @param appLocals - The unnamed application local states that were referenced. The order of this
     * array is arbitrary.
     * @param apps - The unnamed applications that were referenced. The order of this array is
     * arbitrary.
     * @param assetHoldings - The unnamed asset holdings that were referenced. The order of this array is
     * arbitrary.
     * @param assets - The unnamed assets that were referenced. The order of this array is arbitrary.
     * @param boxes - The unnamed boxes that were referenced. The order of this array is arbitrary.
     * @param extraBoxRefs - The number of extra box references used to increase the IO budget. This is in
     * addition to the references defined in the input transaction group and any
     * referenced to unnamed boxes.
     */
    constructor({ accounts, appLocals, apps, assetHoldings, assets, boxes, extraBoxRefs, }: {
        accounts?: (Address | string)[];
        appLocals?: ApplicationLocalReference[];
        apps?: (number | bigint)[];
        assetHoldings?: AssetHoldingReference[];
        assets?: (number | bigint)[];
        boxes?: BoxReference[];
        extraBoxRefs?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): SimulateUnnamedResourcesAccessed;
}
/**
 * The set of parameters and limits override during simulation. If this set of
 * parameters is present, then evaluation parameters may differ from standard
 * evaluation in certain ways.
 */
export declare class SimulationEvalOverrides implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * If true, transactions without signatures are allowed and simulated as if they
     * were properly signed.
     */
    allowEmptySignatures?: boolean;
    /**
     * If true, allows access to unnamed resources during simulation.
     */
    allowUnnamedResources?: boolean;
    /**
     * The extra opcode budget added to each transaction group during simulation
     */
    extraOpcodeBudget?: number;
    /**
     * If true, signers for transactions that are missing signatures will be fixed
     * during evaluation.
     */
    fixSigners?: boolean;
    /**
     * The maximum log calls one can make during simulation
     */
    maxLogCalls?: number;
    /**
     * The maximum byte number to log during simulation
     */
    maxLogSize?: number;
    /**
     * Creates a new `SimulationEvalOverrides` object.
     * @param allowEmptySignatures - If true, transactions without signatures are allowed and simulated as if they
     * were properly signed.
     * @param allowUnnamedResources - If true, allows access to unnamed resources during simulation.
     * @param extraOpcodeBudget - The extra opcode budget added to each transaction group during simulation
     * @param fixSigners - If true, signers for transactions that are missing signatures will be fixed
     * during evaluation.
     * @param maxLogCalls - The maximum log calls one can make during simulation
     * @param maxLogSize - The maximum byte number to log during simulation
     */
    constructor({ allowEmptySignatures, allowUnnamedResources, extraOpcodeBudget, fixSigners, maxLogCalls, maxLogSize, }: {
        allowEmptySignatures?: boolean;
        allowUnnamedResources?: boolean;
        extraOpcodeBudget?: number | bigint;
        fixSigners?: boolean;
        maxLogCalls?: number | bigint;
        maxLogSize?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): SimulationEvalOverrides;
}
/**
 * The set of trace information and effect from evaluating a single opcode.
 */
export declare class SimulationOpcodeTraceUnit implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The program counter of the current opcode being evaluated.
     */
    pc: number;
    /**
     * The writes into scratch slots.
     */
    scratchChanges?: ScratchChange[];
    /**
     * The indexes of the traces for inner transactions spawned by this opcode, if any.
     */
    spawnedInners?: number[];
    /**
     * The values added by this opcode to the stack.
     */
    stackAdditions?: AvmValue[];
    /**
     * The number of deleted stack values by this opcode.
     */
    stackPopCount?: number;
    /**
     * The operations against the current application's states.
     */
    stateChanges?: ApplicationStateOperation[];
    /**
     * Creates a new `SimulationOpcodeTraceUnit` object.
     * @param pc - The program counter of the current opcode being evaluated.
     * @param scratchChanges - The writes into scratch slots.
     * @param spawnedInners - The indexes of the traces for inner transactions spawned by this opcode, if any.
     * @param stackAdditions - The values added by this opcode to the stack.
     * @param stackPopCount - The number of deleted stack values by this opcode.
     * @param stateChanges - The operations against the current application's states.
     */
    constructor({ pc, scratchChanges, spawnedInners, stackAdditions, stackPopCount, stateChanges, }: {
        pc: number | bigint;
        scratchChanges?: ScratchChange[];
        spawnedInners?: (number | bigint)[];
        stackAdditions?: AvmValue[];
        stackPopCount?: number | bigint;
        stateChanges?: ApplicationStateOperation[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): SimulationOpcodeTraceUnit;
}
/**
 * The execution trace of calling an app or a logic sig, containing the inner app
 * call trace in a recursive way.
 */
export declare class SimulationTransactionExecTrace implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * SHA512_256 hash digest of the approval program executed in transaction.
     */
    approvalProgramHash?: Uint8Array;
    /**
     * Program trace that contains a trace of opcode effects in an approval program.
     */
    approvalProgramTrace?: SimulationOpcodeTraceUnit[];
    /**
     * SHA512_256 hash digest of the clear state program executed in transaction.
     */
    clearStateProgramHash?: Uint8Array;
    /**
     * Program trace that contains a trace of opcode effects in a clear state program.
     */
    clearStateProgramTrace?: SimulationOpcodeTraceUnit[];
    /**
     * If true, indicates that the clear state program failed and any persistent state
     * changes it produced should be reverted once the program exits.
     */
    clearStateRollback?: boolean;
    /**
     * The error message explaining why the clear state program failed. This field will
     * only be populated if clear-state-rollback is true and the failure was due to an
     * execution error.
     */
    clearStateRollbackError?: string;
    /**
     * An array of SimulationTransactionExecTrace representing the execution trace of
     * any inner transactions executed.
     */
    innerTrace?: SimulationTransactionExecTrace[];
    /**
     * SHA512_256 hash digest of the logic sig executed in transaction.
     */
    logicSigHash?: Uint8Array;
    /**
     * Program trace that contains a trace of opcode effects in a logic sig.
     */
    logicSigTrace?: SimulationOpcodeTraceUnit[];
    /**
     * Creates a new `SimulationTransactionExecTrace` object.
     * @param approvalProgramHash - SHA512_256 hash digest of the approval program executed in transaction.
     * @param approvalProgramTrace - Program trace that contains a trace of opcode effects in an approval program.
     * @param clearStateProgramHash - SHA512_256 hash digest of the clear state program executed in transaction.
     * @param clearStateProgramTrace - Program trace that contains a trace of opcode effects in a clear state program.
     * @param clearStateRollback - If true, indicates that the clear state program failed and any persistent state
     * changes it produced should be reverted once the program exits.
     * @param clearStateRollbackError - The error message explaining why the clear state program failed. This field will
     * only be populated if clear-state-rollback is true and the failure was due to an
     * execution error.
     * @param innerTrace - An array of SimulationTransactionExecTrace representing the execution trace of
     * any inner transactions executed.
     * @param logicSigHash - SHA512_256 hash digest of the logic sig executed in transaction.
     * @param logicSigTrace - Program trace that contains a trace of opcode effects in a logic sig.
     */
    constructor({ approvalProgramHash, approvalProgramTrace, clearStateProgramHash, clearStateProgramTrace, clearStateRollback, clearStateRollbackError, innerTrace, logicSigHash, logicSigTrace, }: {
        approvalProgramHash?: string | Uint8Array;
        approvalProgramTrace?: SimulationOpcodeTraceUnit[];
        clearStateProgramHash?: string | Uint8Array;
        clearStateProgramTrace?: SimulationOpcodeTraceUnit[];
        clearStateRollback?: boolean;
        clearStateRollbackError?: string;
        innerTrace?: SimulationTransactionExecTrace[];
        logicSigHash?: string | Uint8Array;
        logicSigTrace?: SimulationOpcodeTraceUnit[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): SimulationTransactionExecTrace;
}
/**
 * Represents a state proof and its corresponding message
 */
export declare class StateProof implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Represents the message that the state proofs are attesting to.
     */
    message: StateProofMessage;
    /**
     * The encoded StateProof for the message.
     */
    stateproof: Uint8Array;
    /**
     * Creates a new `StateProof` object.
     * @param message - Represents the message that the state proofs are attesting to.
     * @param stateproof - The encoded StateProof for the message.
     */
    constructor({ message, stateproof, }: {
        message: StateProofMessage;
        stateproof: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): StateProof;
}
/**
 * Represents the message that the state proofs are attesting to.
 */
export declare class StateProofMessage implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The vector commitment root on all light block headers within a state proof
     * interval.
     */
    blockheaderscommitment: Uint8Array;
    /**
     * The first round the message attests to.
     */
    firstattestedround: bigint;
    /**
     * The last round the message attests to.
     */
    lastattestedround: bigint;
    /**
     * An integer value representing the natural log of the proven weight with 16 bits
     * of precision. This value would be used to verify the next state proof.
     */
    lnprovenweight: bigint;
    /**
     * The vector commitment root of the top N accounts to sign the next StateProof.
     */
    voterscommitment: Uint8Array;
    /**
     * Creates a new `StateProofMessage` object.
     * @param blockheaderscommitment - The vector commitment root on all light block headers within a state proof
     * interval.
     * @param firstattestedround - The first round the message attests to.
     * @param lastattestedround - The last round the message attests to.
     * @param lnprovenweight - An integer value representing the natural log of the proven weight with 16 bits
     * of precision. This value would be used to verify the next state proof.
     * @param voterscommitment - The vector commitment root of the top N accounts to sign the next StateProof.
     */
    constructor({ blockheaderscommitment, firstattestedround, lastattestedround, lnprovenweight, voterscommitment, }: {
        blockheaderscommitment: string | Uint8Array;
        firstattestedround: number | bigint;
        lastattestedround: number | bigint;
        lnprovenweight: number | bigint;
        voterscommitment: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): StateProofMessage;
}
/**
 * Supply represents the current supply of MicroAlgos in the system.
 */
export declare class SupplyResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Round
     */
    currentRound: bigint;
    /**
     * OnlineMoney
     */
    onlineMoney: bigint;
    /**
     * TotalMoney
     */
    totalMoney: bigint;
    /**
     * Creates a new `SupplyResponse` object.
     * @param currentRound - Round
     * @param onlineMoney - OnlineMoney
     * @param totalMoney - TotalMoney
     */
    constructor({ currentRound, onlineMoney, totalMoney, }: {
        currentRound: number | bigint;
        onlineMoney: number | bigint;
        totalMoney: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): SupplyResponse;
}
/**
 * Represents a key-value pair in an application store.
 */
export declare class TealKeyValue implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    key: Uint8Array;
    /**
     * Represents a TEAL value.
     */
    value: TealValue;
    /**
     * Creates a new `TealKeyValue` object.
     * @param key -
     * @param value - Represents a TEAL value.
     */
    constructor({ key, value }: {
        key: string | Uint8Array;
        value: TealValue;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TealKeyValue;
}
/**
 * Represents a TEAL value.
 */
export declare class TealValue implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (tb) bytes value.
     */
    bytes: Uint8Array;
    /**
     * (tt) value type. Value `1` refers to **bytes**, value `2` refers to **uint**
     */
    type: number;
    /**
     * (ui) uint value.
     */
    uint: bigint;
    /**
     * Creates a new `TealValue` object.
     * @param bytes - (tb) bytes value.
     * @param type - (tt) value type. Value `1` refers to **bytes**, value `2` refers to **uint**
     * @param uint - (ui) uint value.
     */
    constructor({ bytes, type, uint, }: {
        bytes: string | Uint8Array;
        type: number | bigint;
        uint: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TealValue;
}
/**
 * Response containing all ledger state deltas for transaction groups, with their
 * associated Ids, in a single round.
 */
export declare class TransactionGroupLedgerStateDeltasForRoundResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    deltas: LedgerStateDeltaForTransactionGroup[];
    /**
     * Creates a new `TransactionGroupLedgerStateDeltasForRoundResponse` object.
     * @param deltas -
     */
    constructor({ deltas }: {
        deltas: LedgerStateDeltaForTransactionGroup[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionGroupLedgerStateDeltasForRoundResponse;
}
/**
 * TransactionParams contains the parameters that help a client construct a new
 * transaction.
 */
export declare class TransactionParametersResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * ConsensusVersion indicates the consensus protocol version
     * as of LastRound.
     */
    consensusVersion: string;
    /**
     * Fee is the suggested transaction fee
     * Fee is in units of micro-Algos per byte.
     * Fee may fall to zero but transactions must still have a fee of
     * at least MinTxnFee for the current network protocol.
     */
    fee: bigint;
    /**
     * GenesisHash is the hash of the genesis block.
     */
    genesisHash: Uint8Array;
    /**
     * GenesisID is an ID listed in the genesis block.
     */
    genesisId: string;
    /**
     * LastRound indicates the last round seen
     */
    lastRound: bigint;
    /**
     * The minimum transaction fee (not per byte) required for the
     * txn to validate for the current network protocol.
     */
    minFee: bigint;
    /**
     * Creates a new `TransactionParametersResponse` object.
     * @param consensusVersion - ConsensusVersion indicates the consensus protocol version
     * as of LastRound.
     * @param fee - Fee is the suggested transaction fee
     * Fee is in units of micro-Algos per byte.
     * Fee may fall to zero but transactions must still have a fee of
     * at least MinTxnFee for the current network protocol.
     * @param genesisHash - GenesisHash is the hash of the genesis block.
     * @param genesisId - GenesisID is an ID listed in the genesis block.
     * @param lastRound - LastRound indicates the last round seen
     * @param minFee - The minimum transaction fee (not per byte) required for the
     * txn to validate for the current network protocol.
     */
    constructor({ consensusVersion, fee, genesisHash, genesisId, lastRound, minFee, }: {
        consensusVersion: string;
        fee: number | bigint;
        genesisHash: string | Uint8Array;
        genesisId: string;
        lastRound: number | bigint;
        minFee: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionParametersResponse;
}
/**
 * Proof of transaction in a block.
 */
export declare class TransactionProofResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Index of the transaction in the block's payset.
     */
    idx: number;
    /**
     * Proof of transaction membership.
     */
    proof: Uint8Array;
    /**
     * Hash of SignedTxnInBlock for verifying proof.
     */
    stibhash: Uint8Array;
    /**
     * Represents the depth of the tree that is being proven, i.e. the number of edges
     * from a leaf to the root.
     */
    treedepth: number;
    /**
     * The type of hash function used to create the proof, must be one of:
     * * sha512_256
     * * sha256
     */
    hashtype?: string;
    /**
     * Creates a new `TransactionProofResponse` object.
     * @param idx - Index of the transaction in the block's payset.
     * @param proof - Proof of transaction membership.
     * @param stibhash - Hash of SignedTxnInBlock for verifying proof.
     * @param treedepth - Represents the depth of the tree that is being proven, i.e. the number of edges
     * from a leaf to the root.
     * @param hashtype - The type of hash function used to create the proof, must be one of:
     * * sha512_256
     * * sha256
     */
    constructor({ idx, proof, stibhash, treedepth, hashtype, }: {
        idx: number | bigint;
        proof: string | Uint8Array;
        stibhash: string | Uint8Array;
        treedepth: number | bigint;
        hashtype?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionProofResponse;
}
/**
 * algod version information.
 */
export declare class Version implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    build: BuildVersion;
    genesisHashB64: Uint8Array;
    genesisId: string;
    versions: string[];
    /**
     * Creates a new `Version` object.
     * @param build -
     * @param genesisHashB64 -
     * @param genesisId -
     * @param versions -
     */
    constructor({ build, genesisHashB64, genesisId, versions, }: {
        build: BuildVersion;
        genesisHashB64: string | Uint8Array;
        genesisId: string;
        versions: string[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): Version;
}
