import { HTTPClient, HTTPClientResponse } from '../../client.js';
import JSONRequest from '../jsonrequest.js';
import { Box } from './models/types.js';
export default class LookupApplicationBoxByIDandName extends JSONRequest<Box> {
    private index;
    /**
     * Returns information about indexed application boxes.
     *
     * #### Example
     * ```typescript
     * const boxName = Buffer.from("foo");
     * const boxResponse = await indexerClient
     *        .LookupApplicationBoxByIDandName(1234, boxName)
     *        .do();
     * const boxValue = boxResponse.value;
     * ```
     *
     * [Response data schema details](https://developer.algorand.org/docs/rest-apis/indexer/#get-v2applicationsapplication-idbox)
     * @oaram index - application index.
     * @category GET
     */
    constructor(c: HTTPClient, index: number | bigint, boxName: Uint8Array);
    /**
     * @returns `/v2/applications/${index}/box`
     */
    path(): string;
    prepare(response: HTTPClientResponse): Box;
}
