/**
 * NOTICE: This file was generated. Editing this file manually is not recommended.
 */
import { Encodable, Schema } from '../../../../encoding/encoding.js';
import { Address } from '../../../../encoding/address.js';
import { UntypedValue } from '../../untypedmodel.js';
/**
 * Account information at a given round.
 * Definition:
 * data/basics/userBalance.go : AccountData
 */
export declare class Account implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * the account public key
     */
    address: string;
    /**
     * total number of MicroAlgos in the account
     */
    amount: bigint;
    /**
     * specifies the amount of MicroAlgos in the account, without the pending rewards.
     */
    amountWithoutPendingRewards: bigint;
    /**
     * MicroAlgo balance required by the account.
     * The requirement grows based on asset and application usage.
     */
    minBalance: number;
    /**
     * amount of MicroAlgos of pending rewards in this account.
     */
    pendingRewards: bigint;
    /**
     * total rewards of MicroAlgos the account has received, including pending rewards.
     */
    rewards: bigint;
    /**
     * The round for which this information is relevant.
     */
    round: bigint;
    /**
     * voting status of the account's MicroAlgos
     * * Offline - indicates that the associated account is delegated.
     * * Online - indicates that the associated account used as part of the delegation
     * pool.
     * * NotParticipating - indicates that the associated account is neither a
     * delegator nor a delegate.
     */
    status: string;
    /**
     * The count of all applications that have been opted in, equivalent to the count
     * of application local data (AppLocalState objects) stored in this account.
     */
    totalAppsOptedIn: number;
    /**
     * The count of all assets that have been opted in, equivalent to the count of
     * AssetHolding objects held by this account.
     */
    totalAssetsOptedIn: number;
    /**
     * For app-accounts only. The total number of bytes allocated for the keys and
     * values of boxes which belong to the associated application.
     */
    totalBoxBytes: number;
    /**
     * For app-accounts only. The total number of boxes which belong to the associated
     * application.
     */
    totalBoxes: number;
    /**
     * The count of all apps (AppParams objects) created by this account.
     */
    totalCreatedApps: number;
    /**
     * The count of all assets (AssetParams objects) created by this account.
     */
    totalCreatedAssets: number;
    /**
     * application local data stored in this account.
     * Note the raw object uses `map[int] -> AppLocalState` for this type.
     */
    appsLocalState?: ApplicationLocalState[];
    /**
     * the sum of all extra application program pages for this account.
     */
    appsTotalExtraPages?: number;
    /**
     * the sum of all of the local schemas and global schemas in this account.
     * Note: the raw account uses `StateSchema` for this type.
     */
    appsTotalSchema?: ApplicationStateSchema;
    /**
     * assets held by this account.
     * Note the raw object uses `map[int] -> AssetHolding` for this type.
     */
    assets?: AssetHolding[];
    /**
     * The address against which signing should be checked. If empty, the address of
     * the current account is used. This field can be updated in any transaction by
     * setting the RekeyTo field.
     */
    authAddr?: Address;
    /**
     * Round during which this account was most recently closed.
     */
    closedAtRound?: bigint;
    /**
     * parameters of applications created by this account including app global data.
     * Note: the raw account uses `map[int] -> AppParams` for this type.
     */
    createdApps?: Application[];
    /**
     * parameters of assets created by this account.
     * Note: the raw account uses `map[int] -> Asset` for this type.
     */
    createdAssets?: Asset[];
    /**
     * Round during which this account first appeared in a transaction.
     */
    createdAtRound?: bigint;
    /**
     * Whether or not this account is currently closed.
     */
    deleted?: boolean;
    /**
     * can the account receive block incentives if its balance is in range at proposal
     * time.
     */
    incentiveEligible?: boolean;
    /**
     * The round in which this account last went online, or explicitly renewed their
     * online status.
     */
    lastHeartbeat?: number;
    /**
     * The round in which this account last proposed the block.
     */
    lastProposed?: number;
    /**
     * AccountParticipation describes the parameters used by this account in consensus
     * protocol.
     */
    participation?: AccountParticipation;
    /**
     * used as part of the rewards computation. Only applicable to accounts which are
     * participating.
     */
    rewardBase?: bigint;
    /**
     * the type of signature used by this account, must be one of:
     * * sig
     * * msig
     * * lsig
     * * or null if unknown
     */
    sigType?: string;
    /**
     * Creates a new `Account` object.
     * @param address - the account public key
     * @param amount - total number of MicroAlgos in the account
     * @param amountWithoutPendingRewards - specifies the amount of MicroAlgos in the account, without the pending rewards.
     * @param minBalance - MicroAlgo balance required by the account.
     * The requirement grows based on asset and application usage.
     * @param pendingRewards - amount of MicroAlgos of pending rewards in this account.
     * @param rewards - total rewards of MicroAlgos the account has received, including pending rewards.
     * @param round - The round for which this information is relevant.
     * @param status - voting status of the account's MicroAlgos
     * * Offline - indicates that the associated account is delegated.
     * * Online - indicates that the associated account used as part of the delegation
     * pool.
     * * NotParticipating - indicates that the associated account is neither a
     * delegator nor a delegate.
     * @param totalAppsOptedIn - The count of all applications that have been opted in, equivalent to the count
     * of application local data (AppLocalState objects) stored in this account.
     * @param totalAssetsOptedIn - The count of all assets that have been opted in, equivalent to the count of
     * AssetHolding objects held by this account.
     * @param totalBoxBytes - For app-accounts only. The total number of bytes allocated for the keys and
     * values of boxes which belong to the associated application.
     * @param totalBoxes - For app-accounts only. The total number of boxes which belong to the associated
     * application.
     * @param totalCreatedApps - The count of all apps (AppParams objects) created by this account.
     * @param totalCreatedAssets - The count of all assets (AssetParams objects) created by this account.
     * @param appsLocalState - application local data stored in this account.
     * Note the raw object uses `map[int] -> AppLocalState` for this type.
     * @param appsTotalExtraPages - the sum of all extra application program pages for this account.
     * @param appsTotalSchema - the sum of all of the local schemas and global schemas in this account.
     * Note: the raw account uses `StateSchema` for this type.
     * @param assets - assets held by this account.
     * Note the raw object uses `map[int] -> AssetHolding` for this type.
     * @param authAddr - The address against which signing should be checked. If empty, the address of
     * the current account is used. This field can be updated in any transaction by
     * setting the RekeyTo field.
     * @param closedAtRound - Round during which this account was most recently closed.
     * @param createdApps - parameters of applications created by this account including app global data.
     * Note: the raw account uses `map[int] -> AppParams` for this type.
     * @param createdAssets - parameters of assets created by this account.
     * Note: the raw account uses `map[int] -> Asset` for this type.
     * @param createdAtRound - Round during which this account first appeared in a transaction.
     * @param deleted - Whether or not this account is currently closed.
     * @param incentiveEligible - can the account receive block incentives if its balance is in range at proposal
     * time.
     * @param lastHeartbeat - The round in which this account last went online, or explicitly renewed their
     * online status.
     * @param lastProposed - The round in which this account last proposed the block.
     * @param participation - AccountParticipation describes the parameters used by this account in consensus
     * protocol.
     * @param rewardBase - used as part of the rewards computation. Only applicable to accounts which are
     * participating.
     * @param sigType - the type of signature used by this account, must be one of:
     * * sig
     * * msig
     * * lsig
     * * or null if unknown
     */
    constructor({ address, amount, amountWithoutPendingRewards, minBalance, pendingRewards, rewards, round, status, totalAppsOptedIn, totalAssetsOptedIn, totalBoxBytes, totalBoxes, totalCreatedApps, totalCreatedAssets, appsLocalState, appsTotalExtraPages, appsTotalSchema, assets, authAddr, closedAtRound, createdApps, createdAssets, createdAtRound, deleted, incentiveEligible, lastHeartbeat, lastProposed, participation, rewardBase, sigType, }: {
        address: string;
        amount: number | bigint;
        amountWithoutPendingRewards: number | bigint;
        minBalance: number | bigint;
        pendingRewards: number | bigint;
        rewards: number | bigint;
        round: number | bigint;
        status: string;
        totalAppsOptedIn: number | bigint;
        totalAssetsOptedIn: number | bigint;
        totalBoxBytes: number | bigint;
        totalBoxes: number | bigint;
        totalCreatedApps: number | bigint;
        totalCreatedAssets: number | bigint;
        appsLocalState?: ApplicationLocalState[];
        appsTotalExtraPages?: number | bigint;
        appsTotalSchema?: ApplicationStateSchema;
        assets?: AssetHolding[];
        authAddr?: Address | string;
        closedAtRound?: number | bigint;
        createdApps?: Application[];
        createdAssets?: Asset[];
        createdAtRound?: number | bigint;
        deleted?: boolean;
        incentiveEligible?: boolean;
        lastHeartbeat?: number | bigint;
        lastProposed?: number | bigint;
        participation?: AccountParticipation;
        rewardBase?: number | bigint;
        sigType?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): Account;
}
/**
 * AccountParticipation describes the parameters used by this account in consensus
 * protocol.
 */
export declare class AccountParticipation implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Selection public key (if any) currently registered for this round.
     */
    selectionParticipationKey: Uint8Array;
    /**
     * First round for which this participation is valid.
     */
    voteFirstValid: bigint;
    /**
     * Number of subkeys in each batch of participation keys.
     */
    voteKeyDilution: bigint;
    /**
     * Last round for which this participation is valid.
     */
    voteLastValid: bigint;
    /**
     * root participation public key (if any) currently registered for this round.
     */
    voteParticipationKey: Uint8Array;
    /**
     * Root of the state proof key (if any)
     */
    stateProofKey?: Uint8Array;
    /**
     * Creates a new `AccountParticipation` object.
     * @param selectionParticipationKey - Selection public key (if any) currently registered for this round.
     * @param voteFirstValid - First round for which this participation is valid.
     * @param voteKeyDilution - Number of subkeys in each batch of participation keys.
     * @param voteLastValid - Last round for which this participation is valid.
     * @param voteParticipationKey - root participation public key (if any) currently registered for this round.
     * @param stateProofKey - Root of the state proof key (if any)
     */
    constructor({ selectionParticipationKey, voteFirstValid, voteKeyDilution, voteLastValid, voteParticipationKey, stateProofKey, }: {
        selectionParticipationKey: string | Uint8Array;
        voteFirstValid: number | bigint;
        voteKeyDilution: number | bigint;
        voteLastValid: number | bigint;
        voteParticipationKey: string | Uint8Array;
        stateProofKey?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AccountParticipation;
}
/**
 *
 */
export declare class AccountResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Account information at a given round.
     * Definition:
     * data/basics/userBalance.go : AccountData
     */
    account: Account;
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    /**
     * Creates a new `AccountResponse` object.
     * @param account - Account information at a given round.
     * Definition:
     * data/basics/userBalance.go : AccountData
     * @param currentRound - Round at which the results were computed.
     */
    constructor({ account, currentRound, }: {
        account: Account;
        currentRound: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AccountResponse;
}
/**
 * Application state delta.
 */
export declare class AccountStateDelta implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    address: string;
    /**
     * Application state delta.
     */
    delta: EvalDeltaKeyValue[];
    /**
     * Creates a new `AccountStateDelta` object.
     * @param address -
     * @param delta - Application state delta.
     */
    constructor({ address, delta, }: {
        address: string;
        delta: EvalDeltaKeyValue[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AccountStateDelta;
}
/**
 *
 */
export declare class AccountsResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    accounts: Account[];
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    /**
     * Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    nextToken?: string;
    /**
     * Creates a new `AccountsResponse` object.
     * @param accounts -
     * @param currentRound - Round at which the results were computed.
     * @param nextToken - Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    constructor({ accounts, currentRound, nextToken, }: {
        accounts: Account[];
        currentRound: number | bigint;
        nextToken?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AccountsResponse;
}
/**
 * Application index and its parameters
 */
export declare class Application implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * application index.
     */
    id: bigint;
    /**
     * application parameters.
     */
    params: ApplicationParams;
    /**
     * Round when this application was created.
     */
    createdAtRound?: bigint;
    /**
     * Whether or not this application is currently deleted.
     */
    deleted?: boolean;
    /**
     * Round when this application was deleted.
     */
    deletedAtRound?: bigint;
    /**
     * Creates a new `Application` object.
     * @param id - application index.
     * @param params - application parameters.
     * @param createdAtRound - Round when this application was created.
     * @param deleted - Whether or not this application is currently deleted.
     * @param deletedAtRound - Round when this application was deleted.
     */
    constructor({ id, params, createdAtRound, deleted, deletedAtRound, }: {
        id: number | bigint;
        params: ApplicationParams;
        createdAtRound?: number | bigint;
        deleted?: boolean;
        deletedAtRound?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): Application;
}
/**
 * Stores local state associated with an application.
 */
export declare class ApplicationLocalState implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The application which this local state is for.
     */
    id: bigint;
    /**
     * schema.
     */
    schema: ApplicationStateSchema;
    /**
     * Round when account closed out of the application.
     */
    closedOutAtRound?: bigint;
    /**
     * Whether or not the application local state is currently deleted from its
     * account.
     */
    deleted?: boolean;
    /**
     * storage.
     */
    keyValue?: TealKeyValue[];
    /**
     * Round when the account opted into the application.
     */
    optedInAtRound?: bigint;
    /**
     * Creates a new `ApplicationLocalState` object.
     * @param id - The application which this local state is for.
     * @param schema - schema.
     * @param closedOutAtRound - Round when account closed out of the application.
     * @param deleted - Whether or not the application local state is currently deleted from its
     * account.
     * @param keyValue - storage.
     * @param optedInAtRound - Round when the account opted into the application.
     */
    constructor({ id, schema, closedOutAtRound, deleted, keyValue, optedInAtRound, }: {
        id: number | bigint;
        schema: ApplicationStateSchema;
        closedOutAtRound?: number | bigint;
        deleted?: boolean;
        keyValue?: TealKeyValue[];
        optedInAtRound?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationLocalState;
}
/**
 *
 */
export declare class ApplicationLocalStatesResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    appsLocalStates: ApplicationLocalState[];
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    /**
     * Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    nextToken?: string;
    /**
     * Creates a new `ApplicationLocalStatesResponse` object.
     * @param appsLocalStates -
     * @param currentRound - Round at which the results were computed.
     * @param nextToken - Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    constructor({ appsLocalStates, currentRound, nextToken, }: {
        appsLocalStates: ApplicationLocalState[];
        currentRound: number | bigint;
        nextToken?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationLocalStatesResponse;
}
/**
 * Stores the global information associated with an application.
 */
export declare class ApplicationLogData implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Logs for the application being executed by the transaction.
     */
    logs: Uint8Array[];
    /**
     * Transaction ID
     */
    txid: string;
    /**
     * Creates a new `ApplicationLogData` object.
     * @param logs - Logs for the application being executed by the transaction.
     * @param txid - Transaction ID
     */
    constructor({ logs, txid }: {
        logs: Uint8Array[];
        txid: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationLogData;
}
/**
 *
 */
export declare class ApplicationLogsResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (appidx) application index.
     */
    applicationId: bigint;
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    logData?: ApplicationLogData[];
    /**
     * Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    nextToken?: string;
    /**
     * Creates a new `ApplicationLogsResponse` object.
     * @param applicationId - (appidx) application index.
     * @param currentRound - Round at which the results were computed.
     * @param logData -
     * @param nextToken - Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    constructor({ applicationId, currentRound, logData, nextToken, }: {
        applicationId: number | bigint;
        currentRound: number | bigint;
        logData?: ApplicationLogData[];
        nextToken?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationLogsResponse;
}
/**
 * Stores the global information associated with an application.
 */
export declare class ApplicationParams implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * approval program.
     */
    approvalProgram: Uint8Array;
    /**
     * clear state program.
     */
    clearStateProgram: Uint8Array;
    /**
     * The address that created this application. This is the address where the
     * parameters and global state for this application can be found.
     */
    creator?: Address;
    /**
     * the number of extra program pages available to this app.
     */
    extraProgramPages?: number;
    /**
     * global state
     */
    globalState?: TealKeyValue[];
    /**
     * global schema
     */
    globalStateSchema?: ApplicationStateSchema;
    /**
     * local schema
     */
    localStateSchema?: ApplicationStateSchema;
    /**
     * the number of updates to the application programs
     */
    version?: number;
    /**
     * Creates a new `ApplicationParams` object.
     * @param approvalProgram - approval program.
     * @param clearStateProgram - clear state program.
     * @param creator - The address that created this application. This is the address where the
     * parameters and global state for this application can be found.
     * @param extraProgramPages - the number of extra program pages available to this app.
     * @param globalState - global state
     * @param globalStateSchema - global schema
     * @param localStateSchema - local schema
     * @param version - the number of updates to the application programs
     */
    constructor({ approvalProgram, clearStateProgram, creator, extraProgramPages, globalState, globalStateSchema, localStateSchema, version, }: {
        approvalProgram: string | Uint8Array;
        clearStateProgram: string | Uint8Array;
        creator?: Address | string;
        extraProgramPages?: number | bigint;
        globalState?: TealKeyValue[];
        globalStateSchema?: ApplicationStateSchema;
        localStateSchema?: ApplicationStateSchema;
        version?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationParams;
}
/**
 *
 */
export declare class ApplicationResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    /**
     * Application index and its parameters
     */
    application?: Application;
    /**
     * Creates a new `ApplicationResponse` object.
     * @param currentRound - Round at which the results were computed.
     * @param application - Application index and its parameters
     */
    constructor({ currentRound, application, }: {
        currentRound: number | bigint;
        application?: Application;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationResponse;
}
/**
 * Specifies maximums on the number of each type that may be stored.
 */
export declare class ApplicationStateSchema implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * number of byte slices.
     */
    numByteSlice: number;
    /**
     * number of uints.
     */
    numUint: number;
    /**
     * Creates a new `ApplicationStateSchema` object.
     * @param numByteSlice - number of byte slices.
     * @param numUint - number of uints.
     */
    constructor({ numByteSlice, numUint, }: {
        numByteSlice: number | bigint;
        numUint: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationStateSchema;
}
/**
 *
 */
export declare class ApplicationsResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    applications: Application[];
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    /**
     * Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    nextToken?: string;
    /**
     * Creates a new `ApplicationsResponse` object.
     * @param applications -
     * @param currentRound - Round at which the results were computed.
     * @param nextToken - Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    constructor({ applications, currentRound, nextToken, }: {
        applications: Application[];
        currentRound: number | bigint;
        nextToken?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ApplicationsResponse;
}
/**
 * Specifies both the unique identifier and the parameters for an asset
 */
export declare class Asset implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * unique asset identifier
     */
    index: bigint;
    /**
     * AssetParams specifies the parameters for an asset.
     * (apar) when part of an AssetConfig transaction.
     * Definition:
     * data/transactions/asset.go : AssetParams
     */
    params: AssetParams;
    /**
     * Round during which this asset was created.
     */
    createdAtRound?: bigint;
    /**
     * Whether or not this asset is currently deleted.
     */
    deleted?: boolean;
    /**
     * Round during which this asset was destroyed.
     */
    destroyedAtRound?: bigint;
    /**
     * Creates a new `Asset` object.
     * @param index - unique asset identifier
     * @param params - AssetParams specifies the parameters for an asset.
     * (apar) when part of an AssetConfig transaction.
     * Definition:
     * data/transactions/asset.go : AssetParams
     * @param createdAtRound - Round during which this asset was created.
     * @param deleted - Whether or not this asset is currently deleted.
     * @param destroyedAtRound - Round during which this asset was destroyed.
     */
    constructor({ index, params, createdAtRound, deleted, destroyedAtRound, }: {
        index: number | bigint;
        params: AssetParams;
        createdAtRound?: number | bigint;
        deleted?: boolean;
        destroyedAtRound?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): Asset;
}
/**
 *
 */
export declare class AssetBalancesResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    balances: MiniAssetHolding[];
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    /**
     * Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    nextToken?: string;
    /**
     * Creates a new `AssetBalancesResponse` object.
     * @param balances -
     * @param currentRound - Round at which the results were computed.
     * @param nextToken - Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    constructor({ balances, currentRound, nextToken, }: {
        balances: MiniAssetHolding[];
        currentRound: number | bigint;
        nextToken?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AssetBalancesResponse;
}
/**
 * Describes an asset held by an account.
 * Definition:
 * data/basics/userBalance.go : AssetHolding
 */
export declare class AssetHolding implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * number of units held.
     */
    amount: bigint;
    /**
     * Asset ID of the holding.
     */
    assetId: bigint;
    /**
     * whether or not the holding is frozen.
     */
    isFrozen: boolean;
    /**
     * Whether or not the asset holding is currently deleted from its account.
     */
    deleted?: boolean;
    /**
     * Round during which the account opted into this asset holding.
     */
    optedInAtRound?: bigint;
    /**
     * Round during which the account opted out of this asset holding.
     */
    optedOutAtRound?: bigint;
    /**
     * Creates a new `AssetHolding` object.
     * @param amount - number of units held.
     * @param assetId - Asset ID of the holding.
     * @param isFrozen - whether or not the holding is frozen.
     * @param deleted - Whether or not the asset holding is currently deleted from its account.
     * @param optedInAtRound - Round during which the account opted into this asset holding.
     * @param optedOutAtRound - Round during which the account opted out of this asset holding.
     */
    constructor({ amount, assetId, isFrozen, deleted, optedInAtRound, optedOutAtRound, }: {
        amount: number | bigint;
        assetId: number | bigint;
        isFrozen: boolean;
        deleted?: boolean;
        optedInAtRound?: number | bigint;
        optedOutAtRound?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AssetHolding;
}
/**
 *
 */
export declare class AssetHoldingsResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    assets: AssetHolding[];
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    /**
     * Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    nextToken?: string;
    /**
     * Creates a new `AssetHoldingsResponse` object.
     * @param assets -
     * @param currentRound - Round at which the results were computed.
     * @param nextToken - Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    constructor({ assets, currentRound, nextToken, }: {
        assets: AssetHolding[];
        currentRound: number | bigint;
        nextToken?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AssetHoldingsResponse;
}
/**
 * AssetParams specifies the parameters for an asset.
 * (apar) when part of an AssetConfig transaction.
 * Definition:
 * data/transactions/asset.go : AssetParams
 */
export declare class AssetParams implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * The address that created this asset. This is the address where the parameters
     * for this asset can be found, and also the address where unwanted asset units can
     * be sent in the worst case.
     */
    creator: string;
    /**
     * The number of digits to use after the decimal point when displaying this asset.
     * If 0, the asset is not divisible. If 1, the base unit of the asset is in tenths.
     * If 2, the base unit of the asset is in hundredths, and so on. This value must be
     * between 0 and 19 (inclusive).
     */
    decimals: number;
    /**
     * The total number of units of this asset.
     */
    total: bigint;
    /**
     * Address of account used to clawback holdings of this asset. If empty, clawback
     * is not permitted.
     */
    clawback?: string;
    /**
     * Whether holdings of this asset are frozen by default.
     */
    defaultFrozen?: boolean;
    /**
     * Address of account used to freeze holdings of this asset. If empty, freezing is
     * not permitted.
     */
    freeze?: string;
    /**
     * Address of account used to manage the keys of this asset and to destroy it.
     */
    manager?: string;
    /**
     * A commitment to some unspecified asset metadata. The format of this metadata is
     * up to the application.
     */
    metadataHash?: Uint8Array;
    /**
     * Name of this asset, as supplied by the creator. Included only when the asset
     * name is composed of printable utf-8 characters.
     */
    name?: string;
    /**
     * Base64 encoded name of this asset, as supplied by the creator.
     */
    nameB64?: Uint8Array;
    /**
     * Address of account holding reserve (non-minted) units of this asset.
     */
    reserve?: string;
    /**
     * Name of a unit of this asset, as supplied by the creator. Included only when the
     * name of a unit of this asset is composed of printable utf-8 characters.
     */
    unitName?: string;
    /**
     * Base64 encoded name of a unit of this asset, as supplied by the creator.
     */
    unitNameB64?: Uint8Array;
    /**
     * URL where more information about the asset can be retrieved. Included only when
     * the URL is composed of printable utf-8 characters.
     */
    url?: string;
    /**
     * Base64 encoded URL where more information about the asset can be retrieved.
     */
    urlB64?: Uint8Array;
    /**
     * Creates a new `AssetParams` object.
     * @param creator - The address that created this asset. This is the address where the parameters
     * for this asset can be found, and also the address where unwanted asset units can
     * be sent in the worst case.
     * @param decimals - The number of digits to use after the decimal point when displaying this asset.
     * If 0, the asset is not divisible. If 1, the base unit of the asset is in tenths.
     * If 2, the base unit of the asset is in hundredths, and so on. This value must be
     * between 0 and 19 (inclusive).
     * @param total - The total number of units of this asset.
     * @param clawback - Address of account used to clawback holdings of this asset. If empty, clawback
     * is not permitted.
     * @param defaultFrozen - Whether holdings of this asset are frozen by default.
     * @param freeze - Address of account used to freeze holdings of this asset. If empty, freezing is
     * not permitted.
     * @param manager - Address of account used to manage the keys of this asset and to destroy it.
     * @param metadataHash - A commitment to some unspecified asset metadata. The format of this metadata is
     * up to the application.
     * @param name - Name of this asset, as supplied by the creator. Included only when the asset
     * name is composed of printable utf-8 characters.
     * @param nameB64 - Base64 encoded name of this asset, as supplied by the creator.
     * @param reserve - Address of account holding reserve (non-minted) units of this asset.
     * @param unitName - Name of a unit of this asset, as supplied by the creator. Included only when the
     * name of a unit of this asset is composed of printable utf-8 characters.
     * @param unitNameB64 - Base64 encoded name of a unit of this asset, as supplied by the creator.
     * @param url - URL where more information about the asset can be retrieved. Included only when
     * the URL is composed of printable utf-8 characters.
     * @param urlB64 - Base64 encoded URL where more information about the asset can be retrieved.
     */
    constructor({ creator, decimals, total, clawback, defaultFrozen, freeze, manager, metadataHash, name, nameB64, reserve, unitName, unitNameB64, url, urlB64, }: {
        creator: string;
        decimals: number | bigint;
        total: number | bigint;
        clawback?: string;
        defaultFrozen?: boolean;
        freeze?: string;
        manager?: string;
        metadataHash?: string | Uint8Array;
        name?: string;
        nameB64?: string | Uint8Array;
        reserve?: string;
        unitName?: string;
        unitNameB64?: string | Uint8Array;
        url?: string;
        urlB64?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AssetParams;
}
/**
 *
 */
export declare class AssetResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Specifies both the unique identifier and the parameters for an asset
     */
    asset: Asset;
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    /**
     * Creates a new `AssetResponse` object.
     * @param asset - Specifies both the unique identifier and the parameters for an asset
     * @param currentRound - Round at which the results were computed.
     */
    constructor({ asset, currentRound, }: {
        asset: Asset;
        currentRound: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AssetResponse;
}
/**
 *
 */
export declare class AssetsResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    assets: Asset[];
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    /**
     * Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    nextToken?: string;
    /**
     * Creates a new `AssetsResponse` object.
     * @param assets -
     * @param currentRound - Round at which the results were computed.
     * @param nextToken - Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    constructor({ assets, currentRound, nextToken, }: {
        assets: Asset[];
        currentRound: number | bigint;
        nextToken?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): AssetsResponse;
}
/**
 * Block information.
 * Definition:
 * data/bookkeeping/block.go : Block
 */
export declare class Block implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (gh) hash to which this block belongs.
     */
    genesisHash: Uint8Array;
    /**
     * (gen) ID to which this block belongs.
     */
    genesisId: string;
    /**
     * (prev) Previous block hash.
     */
    previousBlockHash: Uint8Array;
    /**
     * (rnd) Current round on which this block was appended to the chain.
     */
    round: bigint;
    /**
     * (seed) Sortition seed.
     */
    seed: Uint8Array;
    /**
     * (ts) Block creation timestamp in seconds since eposh
     */
    timestamp: number;
    /**
     * (txn) TransactionsRoot authenticates the set of transactions appearing in the
     * block. More specifically, it's the root of a merkle tree whose leaves are the
     * block's Txids, in lexicographic order. For the empty block, it's 0. Note that
     * the TxnRoot does not authenticate the signatures on the transactions, only the
     * transactions themselves. Two blocks with the same transactions but in a
     * different order and with different signatures will have the same TxnRoot.
     */
    transactionsRoot: Uint8Array;
    /**
     * (txn256) TransactionsRootSHA256 is an auxiliary TransactionRoot, built using a
     * vector commitment instead of a merkle tree, and SHA256 hash function instead of
     * the default SHA512_256. This commitment can be used on environments where only
     * the SHA256 function exists.
     */
    transactionsRootSha256: Uint8Array;
    /**
     * the potential bonus payout for this block.
     */
    bonus?: number;
    /**
     * the sum of all fees paid by transactions in this block.
     */
    feesCollected?: number;
    /**
     * Participation account data that needs to be checked/acted on by the network.
     */
    participationUpdates?: ParticipationUpdates;
    /**
     * the proposer of this block.
     */
    proposer?: Address;
    /**
     * the actual amount transferred to the proposer from the fee sink.
     */
    proposerPayout?: number;
    /**
     * Fields relating to rewards,
     */
    rewards?: BlockRewards;
    /**
     * Tracks the status of state proofs.
     */
    stateProofTracking?: StateProofTracking[];
    /**
     * (txns) list of transactions corresponding to a given round.
     */
    transactions?: Transaction[];
    /**
     * (tc) TxnCounter counts the number of transactions committed in the ledger, from
     * the time at which support for this feature was introduced.
     * Specifically, TxnCounter is the number of the next transaction that will be
     * committed after this block. It is 0 when no transactions have ever been
     * committed (since TxnCounter started being supported).
     */
    txnCounter?: number;
    /**
     * Fields relating to a protocol upgrade.
     */
    upgradeState?: BlockUpgradeState;
    /**
     * Fields relating to voting for a protocol upgrade.
     */
    upgradeVote?: BlockUpgradeVote;
    /**
     * Creates a new `Block` object.
     * @param genesisHash - (gh) hash to which this block belongs.
     * @param genesisId - (gen) ID to which this block belongs.
     * @param previousBlockHash - (prev) Previous block hash.
     * @param round - (rnd) Current round on which this block was appended to the chain.
     * @param seed - (seed) Sortition seed.
     * @param timestamp - (ts) Block creation timestamp in seconds since eposh
     * @param transactionsRoot - (txn) TransactionsRoot authenticates the set of transactions appearing in the
     * block. More specifically, it's the root of a merkle tree whose leaves are the
     * block's Txids, in lexicographic order. For the empty block, it's 0. Note that
     * the TxnRoot does not authenticate the signatures on the transactions, only the
     * transactions themselves. Two blocks with the same transactions but in a
     * different order and with different signatures will have the same TxnRoot.
     * @param transactionsRootSha256 - (txn256) TransactionsRootSHA256 is an auxiliary TransactionRoot, built using a
     * vector commitment instead of a merkle tree, and SHA256 hash function instead of
     * the default SHA512_256. This commitment can be used on environments where only
     * the SHA256 function exists.
     * @param bonus - the potential bonus payout for this block.
     * @param feesCollected - the sum of all fees paid by transactions in this block.
     * @param participationUpdates - Participation account data that needs to be checked/acted on by the network.
     * @param proposer - the proposer of this block.
     * @param proposerPayout - the actual amount transferred to the proposer from the fee sink.
     * @param rewards - Fields relating to rewards,
     * @param stateProofTracking - Tracks the status of state proofs.
     * @param transactions - (txns) list of transactions corresponding to a given round.
     * @param txnCounter - (tc) TxnCounter counts the number of transactions committed in the ledger, from
     * the time at which support for this feature was introduced.
     * Specifically, TxnCounter is the number of the next transaction that will be
     * committed after this block. It is 0 when no transactions have ever been
     * committed (since TxnCounter started being supported).
     * @param upgradeState - Fields relating to a protocol upgrade.
     * @param upgradeVote - Fields relating to voting for a protocol upgrade.
     */
    constructor({ genesisHash, genesisId, previousBlockHash, round, seed, timestamp, transactionsRoot, transactionsRootSha256, bonus, feesCollected, participationUpdates, proposer, proposerPayout, rewards, stateProofTracking, transactions, txnCounter, upgradeState, upgradeVote, }: {
        genesisHash: string | Uint8Array;
        genesisId: string;
        previousBlockHash: string | Uint8Array;
        round: number | bigint;
        seed: string | Uint8Array;
        timestamp: number | bigint;
        transactionsRoot: string | Uint8Array;
        transactionsRootSha256: string | Uint8Array;
        bonus?: number | bigint;
        feesCollected?: number | bigint;
        participationUpdates?: ParticipationUpdates;
        proposer?: Address | string;
        proposerPayout?: number | bigint;
        rewards?: BlockRewards;
        stateProofTracking?: StateProofTracking[];
        transactions?: Transaction[];
        txnCounter?: number | bigint;
        upgradeState?: BlockUpgradeState;
        upgradeVote?: BlockUpgradeVote;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): Block;
}
/**
 *
 */
export declare class BlockHeadersResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    blocks: Block[];
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    /**
     * Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    nextToken?: string;
    /**
     * Creates a new `BlockHeadersResponse` object.
     * @param blocks -
     * @param currentRound - Round at which the results were computed.
     * @param nextToken - Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    constructor({ blocks, currentRound, nextToken, }: {
        blocks: Block[];
        currentRound: number | bigint;
        nextToken?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BlockHeadersResponse;
}
/**
 * Fields relating to rewards,
 */
export declare class BlockRewards implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (fees) accepts transaction fees, it can only spend to the incentive pool.
     */
    feeSink: string;
    /**
     * (rwcalr) number of leftover MicroAlgos after the distribution of rewards-rate
     * MicroAlgos for every reward unit in the next round.
     */
    rewardsCalculationRound: bigint;
    /**
     * (earn) How many rewards, in MicroAlgos, have been distributed to each RewardUnit
     * of MicroAlgos since genesis.
     */
    rewardsLevel: bigint;
    /**
     * (rwd) accepts periodic injections from the fee-sink and continually
     * redistributes them as rewards.
     */
    rewardsPool: string;
    /**
     * (rate) Number of new MicroAlgos added to the participation stake from rewards at
     * the next round.
     */
    rewardsRate: bigint;
    /**
     * (frac) Number of leftover MicroAlgos after the distribution of
     * RewardsRate/rewardUnits MicroAlgos for every reward unit in the next round.
     */
    rewardsResidue: bigint;
    /**
     * Creates a new `BlockRewards` object.
     * @param feeSink - (fees) accepts transaction fees, it can only spend to the incentive pool.
     * @param rewardsCalculationRound - (rwcalr) number of leftover MicroAlgos after the distribution of rewards-rate
     * MicroAlgos for every reward unit in the next round.
     * @param rewardsLevel - (earn) How many rewards, in MicroAlgos, have been distributed to each RewardUnit
     * of MicroAlgos since genesis.
     * @param rewardsPool - (rwd) accepts periodic injections from the fee-sink and continually
     * redistributes them as rewards.
     * @param rewardsRate - (rate) Number of new MicroAlgos added to the participation stake from rewards at
     * the next round.
     * @param rewardsResidue - (frac) Number of leftover MicroAlgos after the distribution of
     * RewardsRate/rewardUnits MicroAlgos for every reward unit in the next round.
     */
    constructor({ feeSink, rewardsCalculationRound, rewardsLevel, rewardsPool, rewardsRate, rewardsResidue, }: {
        feeSink: string;
        rewardsCalculationRound: number | bigint;
        rewardsLevel: number | bigint;
        rewardsPool: string;
        rewardsRate: number | bigint;
        rewardsResidue: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BlockRewards;
}
/**
 * Fields relating to a protocol upgrade.
 */
export declare class BlockUpgradeState implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (proto) The current protocol version.
     */
    currentProtocol: string;
    /**
     * (nextproto) The next proposed protocol version.
     */
    nextProtocol?: string;
    /**
     * (nextyes) Number of blocks which approved the protocol upgrade.
     */
    nextProtocolApprovals?: number;
    /**
     * (nextswitch) Round on which the protocol upgrade will take effect.
     */
    nextProtocolSwitchOn?: bigint;
    /**
     * (nextbefore) Deadline round for this protocol upgrade (No votes will be consider
     * after this round).
     */
    nextProtocolVoteBefore?: bigint;
    /**
     * Creates a new `BlockUpgradeState` object.
     * @param currentProtocol - (proto) The current protocol version.
     * @param nextProtocol - (nextproto) The next proposed protocol version.
     * @param nextProtocolApprovals - (nextyes) Number of blocks which approved the protocol upgrade.
     * @param nextProtocolSwitchOn - (nextswitch) Round on which the protocol upgrade will take effect.
     * @param nextProtocolVoteBefore - (nextbefore) Deadline round for this protocol upgrade (No votes will be consider
     * after this round).
     */
    constructor({ currentProtocol, nextProtocol, nextProtocolApprovals, nextProtocolSwitchOn, nextProtocolVoteBefore, }: {
        currentProtocol: string;
        nextProtocol?: string;
        nextProtocolApprovals?: number | bigint;
        nextProtocolSwitchOn?: number | bigint;
        nextProtocolVoteBefore?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BlockUpgradeState;
}
/**
 * Fields relating to voting for a protocol upgrade.
 */
export declare class BlockUpgradeVote implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (upgradeyes) Indicates a yes vote for the current proposal.
     */
    upgradeApprove?: boolean;
    /**
     * (upgradedelay) Indicates the time between acceptance and execution.
     */
    upgradeDelay?: bigint;
    /**
     * (upgradeprop) Indicates a proposed upgrade.
     */
    upgradePropose?: string;
    /**
     * Creates a new `BlockUpgradeVote` object.
     * @param upgradeApprove - (upgradeyes) Indicates a yes vote for the current proposal.
     * @param upgradeDelay - (upgradedelay) Indicates the time between acceptance and execution.
     * @param upgradePropose - (upgradeprop) Indicates a proposed upgrade.
     */
    constructor({ upgradeApprove, upgradeDelay, upgradePropose, }: {
        upgradeApprove?: boolean;
        upgradeDelay?: number | bigint;
        upgradePropose?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BlockUpgradeVote;
}
/**
 * Box name and its content.
 */
export declare class Box implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (name) box name, base64 encoded
     */
    name: Uint8Array;
    /**
     * The round for which this information is relevant
     */
    round: bigint;
    /**
     * (value) box value, base64 encoded.
     */
    value: Uint8Array;
    /**
     * Creates a new `Box` object.
     * @param name - (name) box name, base64 encoded
     * @param round - The round for which this information is relevant
     * @param value - (value) box value, base64 encoded.
     */
    constructor({ name, round, value, }: {
        name: string | Uint8Array;
        round: number | bigint;
        value: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): Box;
}
/**
 * Box descriptor describes an app box without a value.
 */
export declare class BoxDescriptor implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Base64 encoded box name
     */
    name: Uint8Array;
    /**
     * Creates a new `BoxDescriptor` object.
     * @param name - Base64 encoded box name
     */
    constructor({ name }: {
        name: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BoxDescriptor;
}
/**
 * Box names of an application
 */
export declare class BoxesResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (appidx) application index.
     */
    applicationId: bigint;
    boxes: BoxDescriptor[];
    /**
     * Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    nextToken?: string;
    /**
     * Creates a new `BoxesResponse` object.
     * @param applicationId - (appidx) application index.
     * @param boxes -
     * @param nextToken - Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    constructor({ applicationId, boxes, nextToken, }: {
        applicationId: number | bigint;
        boxes: BoxDescriptor[];
        nextToken?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): BoxesResponse;
}
/**
 * Response for errors
 */
export declare class ErrorResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    message: string;
    data?: UntypedValue;
    /**
     * Creates a new `ErrorResponse` object.
     * @param message -
     * @param data -
     */
    constructor({ message, data }: {
        message: string;
        data?: UntypedValue;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ErrorResponse;
}
/**
 * Represents a TEAL value delta.
 */
export declare class EvalDelta implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (at) delta action.
     */
    action: number;
    /**
     * (bs) bytes value.
     */
    bytes?: string;
    /**
     * (ui) uint value.
     */
    uint?: bigint;
    /**
     * Creates a new `EvalDelta` object.
     * @param action - (at) delta action.
     * @param bytes - (bs) bytes value.
     * @param uint - (ui) uint value.
     */
    constructor({ action, bytes, uint, }: {
        action: number | bigint;
        bytes?: string;
        uint?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): EvalDelta;
}
/**
 * Key-value pairs for StateDelta.
 */
export declare class EvalDeltaKeyValue implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    key: string;
    /**
     * Represents a TEAL value delta.
     */
    value: EvalDelta;
    /**
     * Creates a new `EvalDeltaKeyValue` object.
     * @param key -
     * @param value - Represents a TEAL value delta.
     */
    constructor({ key, value }: {
        key: string;
        value: EvalDelta;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): EvalDeltaKeyValue;
}
export declare class HashFactory implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (t)
     */
    hashType?: number;
    /**
     * Creates a new `HashFactory` object.
     * @param hashType - (t)
     */
    constructor({ hashType }: {
        hashType?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): HashFactory;
}
/**
 * (hbprf) HbProof is a signature using HeartbeatAddress's partkey, thereby showing
 * it is online.
 */
export declare class HbProofFields implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (p) Public key of the heartbeat message.
     */
    hbPk?: Uint8Array;
    /**
     * (p1s) Signature of OneTimeSignatureSubkeyOffsetID(PK, Batch, Offset) under the
     * key PK2.
     */
    hbPk1sig?: Uint8Array;
    /**
     * (p2) Key for new-style two-level ephemeral signature.
     */
    hbPk2?: Uint8Array;
    /**
     * (p2s) Signature of OneTimeSignatureSubkeyBatchID(PK2, Batch) under the master
     * key (OneTimeSignatureVerifier).
     */
    hbPk2sig?: Uint8Array;
    /**
     * (s) Signature of the heartbeat message.
     */
    hbSig?: Uint8Array;
    /**
     * Creates a new `HbProofFields` object.
     * @param hbPk - (p) Public key of the heartbeat message.
     * @param hbPk1sig - (p1s) Signature of OneTimeSignatureSubkeyOffsetID(PK, Batch, Offset) under the
     * key PK2.
     * @param hbPk2 - (p2) Key for new-style two-level ephemeral signature.
     * @param hbPk2sig - (p2s) Signature of OneTimeSignatureSubkeyBatchID(PK2, Batch) under the master
     * key (OneTimeSignatureVerifier).
     * @param hbSig - (s) Signature of the heartbeat message.
     */
    constructor({ hbPk, hbPk1sig, hbPk2, hbPk2sig, hbSig, }: {
        hbPk?: string | Uint8Array;
        hbPk1sig?: string | Uint8Array;
        hbPk2?: string | Uint8Array;
        hbPk2sig?: string | Uint8Array;
        hbSig?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): HbProofFields;
}
/**
 * A health check response.
 */
export declare class HealthCheck implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    dbAvailable: boolean;
    isMigrating: boolean;
    message: string;
    round: bigint;
    /**
     * Current version.
     */
    version: string;
    data?: UntypedValue;
    errors?: string[];
    /**
     * Creates a new `HealthCheck` object.
     * @param dbAvailable -
     * @param isMigrating -
     * @param message -
     * @param round -
     * @param version - Current version.
     * @param data -
     * @param errors -
     */
    constructor({ dbAvailable, isMigrating, message, round, version, data, errors, }: {
        dbAvailable: boolean;
        isMigrating: boolean;
        message: string;
        round: number | bigint;
        version: string;
        data?: UntypedValue;
        errors?: string[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): HealthCheck;
}
export declare class IndexerStateProofMessage implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (b)
     */
    blockHeadersCommitment?: Uint8Array;
    /**
     * (f)
     */
    firstAttestedRound?: bigint;
    /**
     * (l)
     */
    latestAttestedRound?: bigint;
    /**
     * (P)
     */
    lnProvenWeight?: bigint;
    /**
     * (v)
     */
    votersCommitment?: Uint8Array;
    /**
     * Creates a new `IndexerStateProofMessage` object.
     * @param blockHeadersCommitment - (b)
     * @param firstAttestedRound - (f)
     * @param latestAttestedRound - (l)
     * @param lnProvenWeight - (P)
     * @param votersCommitment - (v)
     */
    constructor({ blockHeadersCommitment, firstAttestedRound, latestAttestedRound, lnProvenWeight, votersCommitment, }: {
        blockHeadersCommitment?: string | Uint8Array;
        firstAttestedRound?: number | bigint;
        latestAttestedRound?: number | bigint;
        lnProvenWeight?: number | bigint;
        votersCommitment?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): IndexerStateProofMessage;
}
export declare class MerkleArrayProof implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    hashFactory?: HashFactory;
    /**
     * (pth)
     */
    path?: Uint8Array[];
    /**
     * (td)
     */
    treeDepth?: number;
    /**
     * Creates a new `MerkleArrayProof` object.
     * @param hashFactory -
     * @param path - (pth)
     * @param treeDepth - (td)
     */
    constructor({ hashFactory, path, treeDepth, }: {
        hashFactory?: HashFactory;
        path?: Uint8Array[];
        treeDepth?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): MerkleArrayProof;
}
/**
 * A simplified version of AssetHolding
 */
export declare class MiniAssetHolding implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    address: string;
    amount: bigint;
    isFrozen: boolean;
    /**
     * Whether or not this asset holding is currently deleted from its account.
     */
    deleted?: boolean;
    /**
     * Round during which the account opted into the asset.
     */
    optedInAtRound?: bigint;
    /**
     * Round during which the account opted out of the asset.
     */
    optedOutAtRound?: bigint;
    /**
     * Creates a new `MiniAssetHolding` object.
     * @param address -
     * @param amount -
     * @param isFrozen -
     * @param deleted - Whether or not this asset holding is currently deleted from its account.
     * @param optedInAtRound - Round during which the account opted into the asset.
     * @param optedOutAtRound - Round during which the account opted out of the asset.
     */
    constructor({ address, amount, isFrozen, deleted, optedInAtRound, optedOutAtRound, }: {
        address: string;
        amount: number | bigint;
        isFrozen: boolean;
        deleted?: boolean;
        optedInAtRound?: number | bigint;
        optedOutAtRound?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): MiniAssetHolding;
}
/**
 * Participation account data that needs to be checked/acted on by the network.
 */
export declare class ParticipationUpdates implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (partupabs) a list of online accounts that need to be suspended.
     */
    absentParticipationAccounts?: string[];
    /**
     * (partupdrmv) a list of online accounts that needs to be converted to offline
     * since their participation key expired.
     */
    expiredParticipationAccounts?: string[];
    /**
     * Creates a new `ParticipationUpdates` object.
     * @param absentParticipationAccounts - (partupabs) a list of online accounts that need to be suspended.
     * @param expiredParticipationAccounts - (partupdrmv) a list of online accounts that needs to be converted to offline
     * since their participation key expired.
     */
    constructor({ absentParticipationAccounts, expiredParticipationAccounts, }: {
        absentParticipationAccounts?: string[];
        expiredParticipationAccounts?: string[];
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): ParticipationUpdates;
}
/**
 * (sp) represents a state proof.
 * Definition:
 * crypto/stateproof/structs.go : StateProof
 */
export declare class StateProofFields implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (P)
     */
    partProofs?: MerkleArrayProof;
    /**
     * (pr) Sequence of reveal positions.
     */
    positionsToReveal?: bigint[];
    /**
     * (r) Note that this is actually stored as a map[uint64] - Reveal in the actual
     * msgp
     */
    reveals?: StateProofReveal[];
    /**
     * (v) Salt version of the merkle signature.
     */
    saltVersion?: number;
    /**
     * (c)
     */
    sigCommit?: Uint8Array;
    /**
     * (S)
     */
    sigProofs?: MerkleArrayProof;
    /**
     * (w)
     */
    signedWeight?: bigint;
    /**
     * Creates a new `StateProofFields` object.
     * @param partProofs - (P)
     * @param positionsToReveal - (pr) Sequence of reveal positions.
     * @param reveals - (r) Note that this is actually stored as a map[uint64] - Reveal in the actual
     * msgp
     * @param saltVersion - (v) Salt version of the merkle signature.
     * @param sigCommit - (c)
     * @param sigProofs - (S)
     * @param signedWeight - (w)
     */
    constructor({ partProofs, positionsToReveal, reveals, saltVersion, sigCommit, sigProofs, signedWeight, }: {
        partProofs?: MerkleArrayProof;
        positionsToReveal?: (number | bigint)[];
        reveals?: StateProofReveal[];
        saltVersion?: number | bigint;
        sigCommit?: string | Uint8Array;
        sigProofs?: MerkleArrayProof;
        signedWeight?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): StateProofFields;
}
export declare class StateProofParticipant implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (p)
     */
    verifier?: StateProofVerifier;
    /**
     * (w)
     */
    weight?: bigint;
    /**
     * Creates a new `StateProofParticipant` object.
     * @param verifier - (p)
     * @param weight - (w)
     */
    constructor({ verifier, weight, }: {
        verifier?: StateProofVerifier;
        weight?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): StateProofParticipant;
}
export declare class StateProofReveal implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (p)
     */
    participant?: StateProofParticipant;
    /**
     * The position in the signature and participants arrays corresponding to this
     * entry.
     */
    position?: bigint;
    /**
     * (s)
     */
    sigSlot?: StateProofSigSlot;
    /**
     * Creates a new `StateProofReveal` object.
     * @param participant - (p)
     * @param position - The position in the signature and participants arrays corresponding to this
     * entry.
     * @param sigSlot - (s)
     */
    constructor({ participant, position, sigSlot, }: {
        participant?: StateProofParticipant;
        position?: number | bigint;
        sigSlot?: StateProofSigSlot;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): StateProofReveal;
}
export declare class StateProofSigSlot implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (l) The total weight of signatures in the lower-numbered slots.
     */
    lowerSigWeight?: bigint;
    signature?: StateProofSignature;
    /**
     * Creates a new `StateProofSigSlot` object.
     * @param lowerSigWeight - (l) The total weight of signatures in the lower-numbered slots.
     * @param signature -
     */
    constructor({ lowerSigWeight, signature, }: {
        lowerSigWeight?: number | bigint;
        signature?: StateProofSignature;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): StateProofSigSlot;
}
export declare class StateProofSignature implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    falconSignature?: Uint8Array;
    merkleArrayIndex?: number;
    proof?: MerkleArrayProof;
    /**
     * (vkey)
     */
    verifyingKey?: Uint8Array;
    /**
     * Creates a new `StateProofSignature` object.
     * @param falconSignature -
     * @param merkleArrayIndex -
     * @param proof -
     * @param verifyingKey - (vkey)
     */
    constructor({ falconSignature, merkleArrayIndex, proof, verifyingKey, }: {
        falconSignature?: string | Uint8Array;
        merkleArrayIndex?: number | bigint;
        proof?: MerkleArrayProof;
        verifyingKey?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): StateProofSignature;
}
export declare class StateProofTracking implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (n) Next round for which we will accept a state proof transaction.
     */
    nextRound?: bigint;
    /**
     * (t) The total number of microalgos held by the online accounts during the
     * StateProof round.
     */
    onlineTotalWeight?: bigint;
    /**
     * State Proof Type. Note the raw object uses map with this as key.
     */
    type?: number;
    /**
     * (v) Root of a vector commitment containing online accounts that will help sign
     * the proof.
     */
    votersCommitment?: Uint8Array;
    /**
     * Creates a new `StateProofTracking` object.
     * @param nextRound - (n) Next round for which we will accept a state proof transaction.
     * @param onlineTotalWeight - (t) The total number of microalgos held by the online accounts during the
     * StateProof round.
     * @param type - State Proof Type. Note the raw object uses map with this as key.
     * @param votersCommitment - (v) Root of a vector commitment containing online accounts that will help sign
     * the proof.
     */
    constructor({ nextRound, onlineTotalWeight, type, votersCommitment, }: {
        nextRound?: number | bigint;
        onlineTotalWeight?: number | bigint;
        type?: number | bigint;
        votersCommitment?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): StateProofTracking;
}
export declare class StateProofVerifier implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (cmt) Represents the root of the vector commitment tree.
     */
    commitment?: Uint8Array;
    /**
     * (lf) Key lifetime.
     */
    keyLifetime?: bigint;
    /**
     * Creates a new `StateProofVerifier` object.
     * @param commitment - (cmt) Represents the root of the vector commitment tree.
     * @param keyLifetime - (lf) Key lifetime.
     */
    constructor({ commitment, keyLifetime, }: {
        commitment?: string | Uint8Array;
        keyLifetime?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): StateProofVerifier;
}
/**
 * Represents a (apls) local-state or (apgs) global-state schema. These schemas
 * determine how much storage may be used in a local-state or global-state for an
 * application. The more space used, the larger minimum balance must be maintained
 * in the account holding the data.
 */
export declare class StateSchema implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Maximum number of TEAL byte slices that may be stored in the key/value store.
     */
    numByteSlice: number;
    /**
     * Maximum number of TEAL uints that may be stored in the key/value store.
     */
    numUint: number;
    /**
     * Creates a new `StateSchema` object.
     * @param numByteSlice - Maximum number of TEAL byte slices that may be stored in the key/value store.
     * @param numUint - Maximum number of TEAL uints that may be stored in the key/value store.
     */
    constructor({ numByteSlice, numUint, }: {
        numByteSlice: number | bigint;
        numUint: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): StateSchema;
}
/**
 * Represents a key-value pair in an application store.
 */
export declare class TealKeyValue implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    key: Uint8Array;
    /**
     * Represents a TEAL value.
     */
    value: TealValue;
    /**
     * Creates a new `TealKeyValue` object.
     * @param key -
     * @param value - Represents a TEAL value.
     */
    constructor({ key, value }: {
        key: string | Uint8Array;
        value: TealValue;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TealKeyValue;
}
/**
 * Represents a TEAL value.
 */
export declare class TealValue implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * bytes value.
     */
    bytes: Uint8Array;
    /**
     * type of the value. Value `1` refers to **bytes**, value `2` refers to **uint**
     */
    type: number;
    /**
     * uint value.
     */
    uint: bigint;
    /**
     * Creates a new `TealValue` object.
     * @param bytes - bytes value.
     * @param type - type of the value. Value `1` refers to **bytes**, value `2` refers to **uint**
     * @param uint - uint value.
     */
    constructor({ bytes, type, uint, }: {
        bytes: string | Uint8Array;
        type: number | bigint;
        uint: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TealValue;
}
/**
 * Contains all fields common to all transactions and serves as an envelope to all
 * transactions type. Represents both regular and inner transactions.
 * Definition:
 * data/transactions/signedtxn.go : SignedTxn
 * data/transactions/transaction.go : Transaction
 */
export declare class Transaction implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (fee) Transaction fee.
     */
    fee: bigint;
    /**
     * (fv) First valid round for this transaction.
     */
    firstValid: bigint;
    /**
     * (lv) Last valid round for this transaction.
     */
    lastValid: bigint;
    /**
     * (snd) Sender's address.
     */
    sender: string;
    /**
     * Fields for application transactions.
     * Definition:
     * data/transactions/application.go : ApplicationCallTxnFields
     */
    applicationTransaction?: TransactionApplication;
    /**
     * Fields for asset allocation, re-configuration, and destruction.
     * A zero value for asset-id indicates asset creation.
     * A zero value for the params indicates asset destruction.
     * Definition:
     * data/transactions/asset.go : AssetConfigTxnFields
     */
    assetConfigTransaction?: TransactionAssetConfig;
    /**
     * Fields for an asset freeze transaction.
     * Definition:
     * data/transactions/asset.go : AssetFreezeTxnFields
     */
    assetFreezeTransaction?: TransactionAssetFreeze;
    /**
     * Fields for an asset transfer transaction.
     * Definition:
     * data/transactions/asset.go : AssetTransferTxnFields
     */
    assetTransferTransaction?: TransactionAssetTransfer;
    /**
     * (sgnr) this is included with signed transactions when the signing address does
     * not equal the sender. The backend can use this to ensure that auth addr is equal
     * to the accounts auth addr.
     */
    authAddr?: Address;
    /**
     * (rc) rewards applied to close-remainder-to account.
     */
    closeRewards?: bigint;
    /**
     * (ca) closing amount for transaction.
     */
    closingAmount?: bigint;
    /**
     * Round when the transaction was confirmed.
     */
    confirmedRound?: bigint;
    /**
     * Specifies an application index (ID) if an application was created with this
     * transaction.
     */
    createdApplicationIndex?: bigint;
    /**
     * Specifies an asset index (ID) if an asset was created with this transaction.
     */
    createdAssetIndex?: bigint;
    /**
     * (gh) Hash of genesis block.
     */
    genesisHash?: Uint8Array;
    /**
     * (gen) genesis block ID.
     */
    genesisId?: string;
    /**
     * (gd) Global state key/value changes for the application being executed by this
     * transaction.
     */
    globalStateDelta?: EvalDeltaKeyValue[];
    /**
     * (grp) Base64 encoded byte array of a sha512/256 digest. When present indicates
     * that this transaction is part of a transaction group and the value is the
     * sha512/256 hash of the transactions in that group.
     */
    group?: Uint8Array;
    /**
     * Fields for a heartbeat transaction.
     * Definition:
     * data/transactions/heartbeat.go : HeartbeatTxnFields
     */
    heartbeatTransaction?: TransactionHeartbeat;
    /**
     * Transaction ID
     */
    id?: string;
    /**
     * Inner transactions produced by application execution.
     */
    innerTxns?: Transaction[];
    /**
     * Offset into the round where this transaction was confirmed.
     */
    intraRoundOffset?: number;
    /**
     * Fields for a keyreg transaction.
     * Definition:
     * data/transactions/keyreg.go : KeyregTxnFields
     */
    keyregTransaction?: TransactionKeyreg;
    /**
     * (lx) Base64 encoded 32-byte array. Lease enforces mutual exclusion of
     * transactions. If this field is nonzero, then once the transaction is confirmed,
     * it acquires the lease identified by the (Sender, Lease) pair of the transaction
     * until the LastValid round passes. While this transaction possesses the lease, no
     * other transaction specifying this lease can be confirmed.
     */
    lease?: Uint8Array;
    /**
     * (ld) Local state key/value changes for the application being executed by this
     * transaction.
     */
    localStateDelta?: AccountStateDelta[];
    /**
     * (lg) Logs for the application being executed by this transaction.
     */
    logs?: Uint8Array[];
    /**
     * (note) Free form data.
     */
    note?: Uint8Array;
    /**
     * Fields for a payment transaction.
     * Definition:
     * data/transactions/payment.go : PaymentTxnFields
     */
    paymentTransaction?: TransactionPayment;
    /**
     * (rr) rewards applied to receiver account.
     */
    receiverRewards?: bigint;
    /**
     * (rekey) when included in a valid transaction, the accounts auth addr will be
     * updated with this value and future signatures must be signed with the key
     * represented by this address.
     */
    rekeyTo?: Address;
    /**
     * Time when the block this transaction is in was confirmed.
     */
    roundTime?: number;
    /**
     * (rs) rewards applied to sender account.
     */
    senderRewards?: bigint;
    /**
     * Validation signature associated with some data. Only one of the signatures
     * should be provided.
     */
    signature?: TransactionSignature;
    /**
     * Fields for a state proof transaction.
     * Definition:
     * data/transactions/stateproof.go : StateProofTxnFields
     */
    stateProofTransaction?: TransactionStateProof;
    /**
     * (type) Indicates what type of transaction this is. Different types have
     * different fields.
     * Valid types, and where their fields are stored:
     * * (pay) payment-transaction
     * * (keyreg) keyreg-transaction
     * * (acfg) asset-config-transaction
     * * (axfer) asset-transfer-transaction
     * * (afrz) asset-freeze-transaction
     * * (appl) application-transaction
     * * (stpf) state-proof-transaction
     * * (hb) heartbeat-transaction
     */
    txType?: string;
    /**
     * Creates a new `Transaction` object.
     * @param fee - (fee) Transaction fee.
     * @param firstValid - (fv) First valid round for this transaction.
     * @param lastValid - (lv) Last valid round for this transaction.
     * @param sender - (snd) Sender's address.
     * @param applicationTransaction - Fields for application transactions.
     * Definition:
     * data/transactions/application.go : ApplicationCallTxnFields
     * @param assetConfigTransaction - Fields for asset allocation, re-configuration, and destruction.
     * A zero value for asset-id indicates asset creation.
     * A zero value for the params indicates asset destruction.
     * Definition:
     * data/transactions/asset.go : AssetConfigTxnFields
     * @param assetFreezeTransaction - Fields for an asset freeze transaction.
     * Definition:
     * data/transactions/asset.go : AssetFreezeTxnFields
     * @param assetTransferTransaction - Fields for an asset transfer transaction.
     * Definition:
     * data/transactions/asset.go : AssetTransferTxnFields
     * @param authAddr - (sgnr) this is included with signed transactions when the signing address does
     * not equal the sender. The backend can use this to ensure that auth addr is equal
     * to the accounts auth addr.
     * @param closeRewards - (rc) rewards applied to close-remainder-to account.
     * @param closingAmount - (ca) closing amount for transaction.
     * @param confirmedRound - Round when the transaction was confirmed.
     * @param createdApplicationIndex - Specifies an application index (ID) if an application was created with this
     * transaction.
     * @param createdAssetIndex - Specifies an asset index (ID) if an asset was created with this transaction.
     * @param genesisHash - (gh) Hash of genesis block.
     * @param genesisId - (gen) genesis block ID.
     * @param globalStateDelta - (gd) Global state key/value changes for the application being executed by this
     * transaction.
     * @param group - (grp) Base64 encoded byte array of a sha512/256 digest. When present indicates
     * that this transaction is part of a transaction group and the value is the
     * sha512/256 hash of the transactions in that group.
     * @param heartbeatTransaction - Fields for a heartbeat transaction.
     * Definition:
     * data/transactions/heartbeat.go : HeartbeatTxnFields
     * @param id - Transaction ID
     * @param innerTxns - Inner transactions produced by application execution.
     * @param intraRoundOffset - Offset into the round where this transaction was confirmed.
     * @param keyregTransaction - Fields for a keyreg transaction.
     * Definition:
     * data/transactions/keyreg.go : KeyregTxnFields
     * @param lease - (lx) Base64 encoded 32-byte array. Lease enforces mutual exclusion of
     * transactions. If this field is nonzero, then once the transaction is confirmed,
     * it acquires the lease identified by the (Sender, Lease) pair of the transaction
     * until the LastValid round passes. While this transaction possesses the lease, no
     * other transaction specifying this lease can be confirmed.
     * @param localStateDelta - (ld) Local state key/value changes for the application being executed by this
     * transaction.
     * @param logs - (lg) Logs for the application being executed by this transaction.
     * @param note - (note) Free form data.
     * @param paymentTransaction - Fields for a payment transaction.
     * Definition:
     * data/transactions/payment.go : PaymentTxnFields
     * @param receiverRewards - (rr) rewards applied to receiver account.
     * @param rekeyTo - (rekey) when included in a valid transaction, the accounts auth addr will be
     * updated with this value and future signatures must be signed with the key
     * represented by this address.
     * @param roundTime - Time when the block this transaction is in was confirmed.
     * @param senderRewards - (rs) rewards applied to sender account.
     * @param signature - Validation signature associated with some data. Only one of the signatures
     * should be provided.
     * @param stateProofTransaction - Fields for a state proof transaction.
     * Definition:
     * data/transactions/stateproof.go : StateProofTxnFields
     * @param txType - (type) Indicates what type of transaction this is. Different types have
     * different fields.
     * Valid types, and where their fields are stored:
     * * (pay) payment-transaction
     * * (keyreg) keyreg-transaction
     * * (acfg) asset-config-transaction
     * * (axfer) asset-transfer-transaction
     * * (afrz) asset-freeze-transaction
     * * (appl) application-transaction
     * * (stpf) state-proof-transaction
     * * (hb) heartbeat-transaction
     */
    constructor({ fee, firstValid, lastValid, sender, applicationTransaction, assetConfigTransaction, assetFreezeTransaction, assetTransferTransaction, authAddr, closeRewards, closingAmount, confirmedRound, createdApplicationIndex, createdAssetIndex, genesisHash, genesisId, globalStateDelta, group, heartbeatTransaction, id, innerTxns, intraRoundOffset, keyregTransaction, lease, localStateDelta, logs, note, paymentTransaction, receiverRewards, rekeyTo, roundTime, senderRewards, signature, stateProofTransaction, txType, }: {
        fee: number | bigint;
        firstValid: number | bigint;
        lastValid: number | bigint;
        sender: string;
        applicationTransaction?: TransactionApplication;
        assetConfigTransaction?: TransactionAssetConfig;
        assetFreezeTransaction?: TransactionAssetFreeze;
        assetTransferTransaction?: TransactionAssetTransfer;
        authAddr?: Address | string;
        closeRewards?: number | bigint;
        closingAmount?: number | bigint;
        confirmedRound?: number | bigint;
        createdApplicationIndex?: number | bigint;
        createdAssetIndex?: number | bigint;
        genesisHash?: string | Uint8Array;
        genesisId?: string;
        globalStateDelta?: EvalDeltaKeyValue[];
        group?: string | Uint8Array;
        heartbeatTransaction?: TransactionHeartbeat;
        id?: string;
        innerTxns?: Transaction[];
        intraRoundOffset?: number | bigint;
        keyregTransaction?: TransactionKeyreg;
        lease?: string | Uint8Array;
        localStateDelta?: AccountStateDelta[];
        logs?: Uint8Array[];
        note?: string | Uint8Array;
        paymentTransaction?: TransactionPayment;
        receiverRewards?: number | bigint;
        rekeyTo?: Address | string;
        roundTime?: number | bigint;
        senderRewards?: number | bigint;
        signature?: TransactionSignature;
        stateProofTransaction?: TransactionStateProof;
        txType?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): Transaction;
}
/**
 * Fields for application transactions.
 * Definition:
 * data/transactions/application.go : ApplicationCallTxnFields
 */
export declare class TransactionApplication implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (apid) ID of the application being configured or empty if creating.
     */
    applicationId: bigint;
    /**
     * (apat) List of accounts in addition to the sender that may be accessed from the
     * application's approval-program and clear-state-program.
     */
    accounts?: Address[];
    /**
     * (apaa) transaction specific arguments accessed from the application's
     * approval-program and clear-state-program.
     */
    applicationArgs?: Uint8Array[];
    /**
     * (apap) Logic executed for every application transaction, except when
     * on-completion is set to "clear". It can read and write global state for the
     * application, as well as account-specific local state. Approval programs may
     * reject the transaction.
     */
    approvalProgram?: Uint8Array;
    /**
     * (apsu) Logic executed for application transactions with on-completion set to
     * "clear". It can read and write global state for the application, as well as
     * account-specific local state. Clear state programs cannot reject the
     * transaction.
     */
    clearStateProgram?: Uint8Array;
    /**
     * (epp) specifies the additional app program len requested in pages.
     */
    extraProgramPages?: number;
    /**
     * (apfa) Lists the applications in addition to the application-id whose global
     * states may be accessed by this application's approval-program and
     * clear-state-program. The access is read-only.
     */
    foreignApps?: bigint[];
    /**
     * (apas) lists the assets whose parameters may be accessed by this application's
     * ApprovalProgram and ClearStateProgram. The access is read-only.
     */
    foreignAssets?: bigint[];
    /**
     * Represents a (apls) local-state or (apgs) global-state schema. These schemas
     * determine how much storage may be used in a local-state or global-state for an
     * application. The more space used, the larger minimum balance must be maintained
     * in the account holding the data.
     */
    globalStateSchema?: StateSchema;
    /**
     * Represents a (apls) local-state or (apgs) global-state schema. These schemas
     * determine how much storage may be used in a local-state or global-state for an
     * application. The more space used, the larger minimum balance must be maintained
     * in the account holding the data.
     */
    localStateSchema?: StateSchema;
    /**
     * (apan) defines the what additional actions occur with the transaction.
     * Valid types:
     * * noop
     * * optin
     * * closeout
     * * clear
     * * update
     * * update
     * * delete
     */
    onCompletion?: string;
    /**
     * Creates a new `TransactionApplication` object.
     * @param applicationId - (apid) ID of the application being configured or empty if creating.
     * @param accounts - (apat) List of accounts in addition to the sender that may be accessed from the
     * application's approval-program and clear-state-program.
     * @param applicationArgs - (apaa) transaction specific arguments accessed from the application's
     * approval-program and clear-state-program.
     * @param approvalProgram - (apap) Logic executed for every application transaction, except when
     * on-completion is set to "clear". It can read and write global state for the
     * application, as well as account-specific local state. Approval programs may
     * reject the transaction.
     * @param clearStateProgram - (apsu) Logic executed for application transactions with on-completion set to
     * "clear". It can read and write global state for the application, as well as
     * account-specific local state. Clear state programs cannot reject the
     * transaction.
     * @param extraProgramPages - (epp) specifies the additional app program len requested in pages.
     * @param foreignApps - (apfa) Lists the applications in addition to the application-id whose global
     * states may be accessed by this application's approval-program and
     * clear-state-program. The access is read-only.
     * @param foreignAssets - (apas) lists the assets whose parameters may be accessed by this application's
     * ApprovalProgram and ClearStateProgram. The access is read-only.
     * @param globalStateSchema - Represents a (apls) local-state or (apgs) global-state schema. These schemas
     * determine how much storage may be used in a local-state or global-state for an
     * application. The more space used, the larger minimum balance must be maintained
     * in the account holding the data.
     * @param localStateSchema - Represents a (apls) local-state or (apgs) global-state schema. These schemas
     * determine how much storage may be used in a local-state or global-state for an
     * application. The more space used, the larger minimum balance must be maintained
     * in the account holding the data.
     * @param onCompletion - (apan) defines the what additional actions occur with the transaction.
     * Valid types:
     * * noop
     * * optin
     * * closeout
     * * clear
     * * update
     * * update
     * * delete
     */
    constructor({ applicationId, accounts, applicationArgs, approvalProgram, clearStateProgram, extraProgramPages, foreignApps, foreignAssets, globalStateSchema, localStateSchema, onCompletion, }: {
        applicationId: number | bigint;
        accounts?: (Address | string)[];
        applicationArgs?: Uint8Array[];
        approvalProgram?: string | Uint8Array;
        clearStateProgram?: string | Uint8Array;
        extraProgramPages?: number | bigint;
        foreignApps?: (number | bigint)[];
        foreignAssets?: (number | bigint)[];
        globalStateSchema?: StateSchema;
        localStateSchema?: StateSchema;
        onCompletion?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionApplication;
}
/**
 * Fields for asset allocation, re-configuration, and destruction.
 * A zero value for asset-id indicates asset creation.
 * A zero value for the params indicates asset destruction.
 * Definition:
 * data/transactions/asset.go : AssetConfigTxnFields
 */
export declare class TransactionAssetConfig implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (xaid) ID of the asset being configured or empty if creating.
     */
    assetId?: bigint;
    /**
     * AssetParams specifies the parameters for an asset.
     * (apar) when part of an AssetConfig transaction.
     * Definition:
     * data/transactions/asset.go : AssetParams
     */
    params?: AssetParams;
    /**
     * Creates a new `TransactionAssetConfig` object.
     * @param assetId - (xaid) ID of the asset being configured or empty if creating.
     * @param params - AssetParams specifies the parameters for an asset.
     * (apar) when part of an AssetConfig transaction.
     * Definition:
     * data/transactions/asset.go : AssetParams
     */
    constructor({ assetId, params, }: {
        assetId?: number | bigint;
        params?: AssetParams;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionAssetConfig;
}
/**
 * Fields for an asset freeze transaction.
 * Definition:
 * data/transactions/asset.go : AssetFreezeTxnFields
 */
export declare class TransactionAssetFreeze implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (fadd) Address of the account whose asset is being frozen or thawed.
     */
    address: string;
    /**
     * (faid) ID of the asset being frozen or thawed.
     */
    assetId: bigint;
    /**
     * (afrz) The new freeze status.
     */
    newFreezeStatus: boolean;
    /**
     * Creates a new `TransactionAssetFreeze` object.
     * @param address - (fadd) Address of the account whose asset is being frozen or thawed.
     * @param assetId - (faid) ID of the asset being frozen or thawed.
     * @param newFreezeStatus - (afrz) The new freeze status.
     */
    constructor({ address, assetId, newFreezeStatus, }: {
        address: string;
        assetId: number | bigint;
        newFreezeStatus: boolean;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionAssetFreeze;
}
/**
 * Fields for an asset transfer transaction.
 * Definition:
 * data/transactions/asset.go : AssetTransferTxnFields
 */
export declare class TransactionAssetTransfer implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (aamt) Amount of asset to transfer. A zero amount transferred to self allocates
     * that asset in the account's Assets map.
     */
    amount: bigint;
    /**
     * (xaid) ID of the asset being transferred.
     */
    assetId: bigint;
    /**
     * (arcv) Recipient address of the transfer.
     */
    receiver: string;
    /**
     * Number of assets transferred to the close-to account as part of the transaction.
     */
    closeAmount?: bigint;
    /**
     * (aclose) Indicates that the asset should be removed from the account's Assets
     * map, and specifies where the remaining asset holdings should be transferred.
     * It's always valid to transfer remaining asset holdings to the creator account.
     */
    closeTo?: string;
    /**
     * (asnd) The effective sender during a clawback transactions. If this is not a
     * zero value, the real transaction sender must be the Clawback address from the
     * AssetParams.
     */
    sender?: string;
    /**
     * Creates a new `TransactionAssetTransfer` object.
     * @param amount - (aamt) Amount of asset to transfer. A zero amount transferred to self allocates
     * that asset in the account's Assets map.
     * @param assetId - (xaid) ID of the asset being transferred.
     * @param receiver - (arcv) Recipient address of the transfer.
     * @param closeAmount - Number of assets transferred to the close-to account as part of the transaction.
     * @param closeTo - (aclose) Indicates that the asset should be removed from the account's Assets
     * map, and specifies where the remaining asset holdings should be transferred.
     * It's always valid to transfer remaining asset holdings to the creator account.
     * @param sender - (asnd) The effective sender during a clawback transactions. If this is not a
     * zero value, the real transaction sender must be the Clawback address from the
     * AssetParams.
     */
    constructor({ amount, assetId, receiver, closeAmount, closeTo, sender, }: {
        amount: number | bigint;
        assetId: number | bigint;
        receiver: string;
        closeAmount?: number | bigint;
        closeTo?: string;
        sender?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionAssetTransfer;
}
/**
 * Fields for a heartbeat transaction.
 * Definition:
 * data/transactions/heartbeat.go : HeartbeatTxnFields
 */
export declare class TransactionHeartbeat implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (hbad) HbAddress is the account this txn is proving onlineness for.
     */
    hbAddress: string;
    /**
     * (hbkd) HbKeyDilution must match HbAddress account's current KeyDilution.
     */
    hbKeyDilution: bigint;
    /**
     * (hbprf) HbProof is a signature using HeartbeatAddress's partkey, thereby showing
     * it is online.
     */
    hbProof: HbProofFields;
    /**
     * (hbsd) HbSeed must be the block seed for the this transaction's firstValid
     * block.
     */
    hbSeed: Uint8Array;
    /**
     * (hbvid) HbVoteID must match the HbAddress account's current VoteID.
     */
    hbVoteId: Uint8Array;
    /**
     * Creates a new `TransactionHeartbeat` object.
     * @param hbAddress - (hbad) HbAddress is the account this txn is proving onlineness for.
     * @param hbKeyDilution - (hbkd) HbKeyDilution must match HbAddress account's current KeyDilution.
     * @param hbProof - (hbprf) HbProof is a signature using HeartbeatAddress's partkey, thereby showing
     * it is online.
     * @param hbSeed - (hbsd) HbSeed must be the block seed for the this transaction's firstValid
     * block.
     * @param hbVoteId - (hbvid) HbVoteID must match the HbAddress account's current VoteID.
     */
    constructor({ hbAddress, hbKeyDilution, hbProof, hbSeed, hbVoteId, }: {
        hbAddress: string;
        hbKeyDilution: number | bigint;
        hbProof: HbProofFields;
        hbSeed: string | Uint8Array;
        hbVoteId: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionHeartbeat;
}
/**
 * Fields for a keyreg transaction.
 * Definition:
 * data/transactions/keyreg.go : KeyregTxnFields
 */
export declare class TransactionKeyreg implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (nonpart) Mark the account as participating or non-participating.
     */
    nonParticipation?: boolean;
    /**
     * (selkey) Public key used with the Verified Random Function (VRF) result during
     * committee selection.
     */
    selectionParticipationKey?: Uint8Array;
    /**
     * (sprfkey) State proof key used in key registration transactions.
     */
    stateProofKey?: Uint8Array;
    /**
     * (votefst) First round this participation key is valid.
     */
    voteFirstValid?: bigint;
    /**
     * (votekd) Number of subkeys in each batch of participation keys.
     */
    voteKeyDilution?: bigint;
    /**
     * (votelst) Last round this participation key is valid.
     */
    voteLastValid?: bigint;
    /**
     * (votekey) Participation public key used in key registration transactions.
     */
    voteParticipationKey?: Uint8Array;
    /**
     * Creates a new `TransactionKeyreg` object.
     * @param nonParticipation - (nonpart) Mark the account as participating or non-participating.
     * @param selectionParticipationKey - (selkey) Public key used with the Verified Random Function (VRF) result during
     * committee selection.
     * @param stateProofKey - (sprfkey) State proof key used in key registration transactions.
     * @param voteFirstValid - (votefst) First round this participation key is valid.
     * @param voteKeyDilution - (votekd) Number of subkeys in each batch of participation keys.
     * @param voteLastValid - (votelst) Last round this participation key is valid.
     * @param voteParticipationKey - (votekey) Participation public key used in key registration transactions.
     */
    constructor({ nonParticipation, selectionParticipationKey, stateProofKey, voteFirstValid, voteKeyDilution, voteLastValid, voteParticipationKey, }: {
        nonParticipation?: boolean;
        selectionParticipationKey?: string | Uint8Array;
        stateProofKey?: string | Uint8Array;
        voteFirstValid?: number | bigint;
        voteKeyDilution?: number | bigint;
        voteLastValid?: number | bigint;
        voteParticipationKey?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionKeyreg;
}
/**
 * Fields for a payment transaction.
 * Definition:
 * data/transactions/payment.go : PaymentTxnFields
 */
export declare class TransactionPayment implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (amt) number of MicroAlgos intended to be transferred.
     */
    amount: bigint;
    /**
     * (rcv) receiver's address.
     */
    receiver: string;
    /**
     * Number of MicroAlgos that were sent to the close-remainder-to address when
     * closing the sender account.
     */
    closeAmount?: bigint;
    /**
     * (close) when set, indicates that the sending account should be closed and all
     * remaining funds be transferred to this address.
     */
    closeRemainderTo?: string;
    /**
     * Creates a new `TransactionPayment` object.
     * @param amount - (amt) number of MicroAlgos intended to be transferred.
     * @param receiver - (rcv) receiver's address.
     * @param closeAmount - Number of MicroAlgos that were sent to the close-remainder-to address when
     * closing the sender account.
     * @param closeRemainderTo - (close) when set, indicates that the sending account should be closed and all
     * remaining funds be transferred to this address.
     */
    constructor({ amount, receiver, closeAmount, closeRemainderTo, }: {
        amount: number | bigint;
        receiver: string;
        closeAmount?: number | bigint;
        closeRemainderTo?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionPayment;
}
/**
 *
 */
export declare class TransactionResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    /**
     * Contains all fields common to all transactions and serves as an envelope to all
     * transactions type. Represents both regular and inner transactions.
     * Definition:
     * data/transactions/signedtxn.go : SignedTxn
     * data/transactions/transaction.go : Transaction
     */
    transaction: Transaction;
    /**
     * Creates a new `TransactionResponse` object.
     * @param currentRound - Round at which the results were computed.
     * @param transaction - Contains all fields common to all transactions and serves as an envelope to all
     * transactions type. Represents both regular and inner transactions.
     * Definition:
     * data/transactions/signedtxn.go : SignedTxn
     * data/transactions/transaction.go : Transaction
     */
    constructor({ currentRound, transaction, }: {
        currentRound: number | bigint;
        transaction: Transaction;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionResponse;
}
/**
 * Validation signature associated with some data. Only one of the signatures
 * should be provided.
 */
export declare class TransactionSignature implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (lsig) Programatic transaction signature.
     * Definition:
     * data/transactions/logicsig.go
     */
    logicsig?: TransactionSignatureLogicsig;
    /**
     * (msig) structure holding multiple subsignatures.
     * Definition:
     * crypto/multisig.go : MultisigSig
     */
    multisig?: TransactionSignatureMultisig;
    /**
     * (sig) Standard ed25519 signature.
     */
    sig?: Uint8Array;
    /**
     * Creates a new `TransactionSignature` object.
     * @param logicsig - (lsig) Programatic transaction signature.
     * Definition:
     * data/transactions/logicsig.go
     * @param multisig - (msig) structure holding multiple subsignatures.
     * Definition:
     * crypto/multisig.go : MultisigSig
     * @param sig - (sig) Standard ed25519 signature.
     */
    constructor({ logicsig, multisig, sig, }: {
        logicsig?: TransactionSignatureLogicsig;
        multisig?: TransactionSignatureMultisig;
        sig?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionSignature;
}
/**
 * (lsig) Programatic transaction signature.
 * Definition:
 * data/transactions/logicsig.go
 */
export declare class TransactionSignatureLogicsig implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (l) Program signed by a signature or multi signature, or hashed to be the
     * address of ana ccount. Base64 encoded TEAL program.
     */
    logic: Uint8Array;
    /**
     * (arg) Logic arguments, base64 encoded.
     */
    args?: Uint8Array[];
    /**
     * (msig) structure holding multiple subsignatures.
     * Definition:
     * crypto/multisig.go : MultisigSig
     */
    multisigSignature?: TransactionSignatureMultisig;
    /**
     * (sig) ed25519 signature.
     */
    signature?: Uint8Array;
    /**
     * Creates a new `TransactionSignatureLogicsig` object.
     * @param logic - (l) Program signed by a signature or multi signature, or hashed to be the
     * address of ana ccount. Base64 encoded TEAL program.
     * @param args - (arg) Logic arguments, base64 encoded.
     * @param multisigSignature - (msig) structure holding multiple subsignatures.
     * Definition:
     * crypto/multisig.go : MultisigSig
     * @param signature - (sig) ed25519 signature.
     */
    constructor({ logic, args, multisigSignature, signature, }: {
        logic: string | Uint8Array;
        args?: Uint8Array[];
        multisigSignature?: TransactionSignatureMultisig;
        signature?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionSignatureLogicsig;
}
/**
 * (msig) structure holding multiple subsignatures.
 * Definition:
 * crypto/multisig.go : MultisigSig
 */
export declare class TransactionSignatureMultisig implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (subsig) holds pairs of public key and signatures.
     */
    subsignature?: TransactionSignatureMultisigSubsignature[];
    /**
     * (thr)
     */
    threshold?: number;
    /**
     * (v)
     */
    version?: number;
    /**
     * Creates a new `TransactionSignatureMultisig` object.
     * @param subsignature - (subsig) holds pairs of public key and signatures.
     * @param threshold - (thr)
     * @param version - (v)
     */
    constructor({ subsignature, threshold, version, }: {
        subsignature?: TransactionSignatureMultisigSubsignature[];
        threshold?: number | bigint;
        version?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionSignatureMultisig;
}
export declare class TransactionSignatureMultisigSubsignature implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (pk)
     */
    publicKey?: Uint8Array;
    /**
     * (s)
     */
    signature?: Uint8Array;
    /**
     * Creates a new `TransactionSignatureMultisigSubsignature` object.
     * @param publicKey - (pk)
     * @param signature - (s)
     */
    constructor({ publicKey, signature, }: {
        publicKey?: string | Uint8Array;
        signature?: string | Uint8Array;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionSignatureMultisigSubsignature;
}
/**
 * Fields for a state proof transaction.
 * Definition:
 * data/transactions/stateproof.go : StateProofTxnFields
 */
export declare class TransactionStateProof implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * (spmsg)
     */
    message?: IndexerStateProofMessage;
    /**
     * (sp) represents a state proof.
     * Definition:
     * crypto/stateproof/structs.go : StateProof
     */
    stateProof?: StateProofFields;
    /**
     * (sptype) Type of the state proof. Integer representing an entry defined in
     * protocol/stateproof.go
     */
    stateProofType?: number;
    /**
     * Creates a new `TransactionStateProof` object.
     * @param message - (spmsg)
     * @param stateProof - (sp) represents a state proof.
     * Definition:
     * crypto/stateproof/structs.go : StateProof
     * @param stateProofType - (sptype) Type of the state proof. Integer representing an entry defined in
     * protocol/stateproof.go
     */
    constructor({ message, stateProof, stateProofType, }: {
        message?: IndexerStateProofMessage;
        stateProof?: StateProofFields;
        stateProofType?: number | bigint;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionStateProof;
}
/**
 *
 */
export declare class TransactionsResponse implements Encodable {
    private static encodingSchemaValue;
    static get encodingSchema(): Schema;
    /**
     * Round at which the results were computed.
     */
    currentRound: bigint;
    transactions: Transaction[];
    /**
     * Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    nextToken?: string;
    /**
     * Creates a new `TransactionsResponse` object.
     * @param currentRound - Round at which the results were computed.
     * @param transactions -
     * @param nextToken - Used for pagination, when making another request provide this token with the
     * next parameter.
     */
    constructor({ currentRound, transactions, nextToken, }: {
        currentRound: number | bigint;
        transactions: Transaction[];
        nextToken?: string;
    });
    getEncodingSchema(): Schema;
    toEncodingData(): Map<string, unknown>;
    static fromEncodingData(data: unknown): TransactionsResponse;
}
